# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class BatchGetVideoClipTaskResponseBody(DaraModel):
    def __init__(
        self,
        request_id: str = None,
        task_list: List[main_models.BatchGetVideoClipTaskResponseBodyTaskList] = None,
    ):
        self.request_id = request_id
        self.task_list = task_list

    def validate(self):
        if self.task_list:
            for v1 in self.task_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.request_id is not None:
            result['requestId'] = self.request_id

        result['taskList'] = []
        if self.task_list is not None:
            for k1 in self.task_list:
                result['taskList'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        self.task_list = []
        if m.get('taskList') is not None:
            for k1 in m.get('taskList'):
                temp_model = main_models.BatchGetVideoClipTaskResponseBodyTaskList()
                self.task_list.append(temp_model.from_map(k1))

        return self

class BatchGetVideoClipTaskResponseBodyTaskList(DaraModel):
    def __init__(
        self,
        status: str = None,
        task_id: str = None,
        total_duration: float = None,
        total_token: int = None,
        video_list: List[main_models.BatchGetVideoClipTaskResponseBodyTaskListVideoList] = None,
    ):
        self.status = status
        self.task_id = task_id
        self.total_duration = total_duration
        self.total_token = total_token
        self.video_list = video_list

    def validate(self):
        if self.video_list:
            for v1 in self.video_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.status is not None:
            result['status'] = self.status

        if self.task_id is not None:
            result['taskId'] = self.task_id

        if self.total_duration is not None:
            result['totalDuration'] = self.total_duration

        if self.total_token is not None:
            result['totalToken'] = self.total_token

        result['videoList'] = []
        if self.video_list is not None:
            for k1 in self.video_list:
                result['videoList'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('status') is not None:
            self.status = m.get('status')

        if m.get('taskId') is not None:
            self.task_id = m.get('taskId')

        if m.get('totalDuration') is not None:
            self.total_duration = m.get('totalDuration')

        if m.get('totalToken') is not None:
            self.total_token = m.get('totalToken')

        self.video_list = []
        if m.get('videoList') is not None:
            for k1 in m.get('videoList'):
                temp_model = main_models.BatchGetVideoClipTaskResponseBodyTaskListVideoList()
                self.video_list.append(temp_model.from_map(k1))

        return self

class BatchGetVideoClipTaskResponseBodyTaskListVideoList(DaraModel):
    def __init__(
        self,
        begin_time: int = None,
        description: str = None,
        end_time: int = None,
        error_msg: str = None,
        title: str = None,
        video_download_url: str = None,
        video_name: str = None,
        video_url: str = None,
    ):
        self.begin_time = begin_time
        self.description = description
        self.end_time = end_time
        self.error_msg = error_msg
        self.title = title
        self.video_download_url = video_download_url
        self.video_name = video_name
        self.video_url = video_url

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.begin_time is not None:
            result['beginTime'] = self.begin_time

        if self.description is not None:
            result['description'] = self.description

        if self.end_time is not None:
            result['endTime'] = self.end_time

        if self.error_msg is not None:
            result['errorMsg'] = self.error_msg

        if self.title is not None:
            result['title'] = self.title

        if self.video_download_url is not None:
            result['videoDownloadUrl'] = self.video_download_url

        if self.video_name is not None:
            result['videoName'] = self.video_name

        if self.video_url is not None:
            result['videoUrl'] = self.video_url

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('beginTime') is not None:
            self.begin_time = m.get('beginTime')

        if m.get('description') is not None:
            self.description = m.get('description')

        if m.get('endTime') is not None:
            self.end_time = m.get('endTime')

        if m.get('errorMsg') is not None:
            self.error_msg = m.get('errorMsg')

        if m.get('title') is not None:
            self.title = m.get('title')

        if m.get('videoDownloadUrl') is not None:
            self.video_download_url = m.get('videoDownloadUrl')

        if m.get('videoName') is not None:
            self.video_name = m.get('videoName')

        if m.get('videoUrl') is not None:
            self.video_url = m.get('videoUrl')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ListAICoachScriptPageRequest(DaraModel):
    def __init__(
        self,
        name: str = None,
        page_number: int = None,
        page_size: int = None,
        status: int = None,
        type: int = None,
    ):
        self.name = name
        self.page_number = page_number
        self.page_size = page_size
        self.status = status
        self.type = type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.name is not None:
            result['name'] = self.name

        if self.page_number is not None:
            result['pageNumber'] = self.page_number

        if self.page_size is not None:
            result['pageSize'] = self.page_size

        if self.status is not None:
            result['status'] = self.status

        if self.type is not None:
            result['type'] = self.type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('pageNumber') is not None:
            self.page_number = m.get('pageNumber')

        if m.get('pageSize') is not None:
            self.page_size = m.get('pageSize')

        if m.get('status') is not None:
            self.status = m.get('status')

        if m.get('type') is not None:
            self.type = m.get('type')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class BatchCreateAICoachTaskRequest(DaraModel):
    def __init__(
        self,
        request_id: str = None,
        script_record_id: str = None,
        student_ids: List[str] = None,
        student_list: List[main_models.BatchCreateAICoachTaskRequestStudentList] = None,
    ):
        self.request_id = request_id
        self.script_record_id = script_record_id
        self.student_ids = student_ids
        self.student_list = student_list

    def validate(self):
        if self.student_list:
            for v1 in self.student_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.script_record_id is not None:
            result['scriptRecordId'] = self.script_record_id

        if self.student_ids is not None:
            result['studentIds'] = self.student_ids

        result['studentList'] = []
        if self.student_list is not None:
            for k1 in self.student_list:
                result['studentList'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('scriptRecordId') is not None:
            self.script_record_id = m.get('scriptRecordId')

        if m.get('studentIds') is not None:
            self.student_ids = m.get('studentIds')

        self.student_list = []
        if m.get('studentList') is not None:
            for k1 in m.get('studentList'):
                temp_model = main_models.BatchCreateAICoachTaskRequestStudentList()
                self.student_list.append(temp_model.from_map(k1))

        return self



class BatchCreateAICoachTaskRequestStudentList(DaraModel):
    def __init__(
        self,
        student_audio_url: str = None,
        student_id: str = None,
    ):
        self.student_audio_url = student_audio_url
        self.student_id = student_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.student_audio_url is not None:
            result['studentAudioUrl'] = self.student_audio_url

        if self.student_id is not None:
            result['studentId'] = self.student_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('studentAudioUrl') is not None:
            self.student_audio_url = m.get('studentAudioUrl')

        if m.get('studentId') is not None:
            self.student_id = m.get('studentId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetAICoachTaskSessionResourceUsageResponseBody(DaraModel):
    def __init__(
        self,
        audio_usage: int = None,
        deduction_status: int = None,
        error_code: str = None,
        error_message: str = None,
        request_id: str = None,
        success: bool = None,
        token_usage: int = None,
    ):
        self.audio_usage = audio_usage
        self.deduction_status = deduction_status
        self.error_code = error_code
        self.error_message = error_message
        # Id of the request
        self.request_id = request_id
        self.success = success
        self.token_usage = token_usage

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.audio_usage is not None:
            result['audioUsage'] = self.audio_usage

        if self.deduction_status is not None:
            result['deductionStatus'] = self.deduction_status

        if self.error_code is not None:
            result['errorCode'] = self.error_code

        if self.error_message is not None:
            result['errorMessage'] = self.error_message

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.success is not None:
            result['success'] = self.success

        if self.token_usage is not None:
            result['tokenUsage'] = self.token_usage

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('audioUsage') is not None:
            self.audio_usage = m.get('audioUsage')

        if m.get('deductionStatus') is not None:
            self.deduction_status = m.get('deductionStatus')

        if m.get('errorCode') is not None:
            self.error_code = m.get('errorCode')

        if m.get('errorMessage') is not None:
            self.error_message = m.get('errorMessage')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('success') is not None:
            self.success = m.get('success')

        if m.get('tokenUsage') is not None:
            self.token_usage = m.get('tokenUsage')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class CreateAnchorRequest(DaraModel):
    def __init__(
        self,
        anchor_category: str = None,
        anchor_material_name: str = None,
        cover_url: str = None,
        digital_human_type: str = None,
        gender: str = None,
        use_scene: str = None,
        video_oss_key: str = None,
    ):
        self.anchor_category = anchor_category
        self.anchor_material_name = anchor_material_name
        self.cover_url = cover_url
        self.digital_human_type = digital_human_type
        self.gender = gender
        self.use_scene = use_scene
        self.video_oss_key = video_oss_key

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.anchor_category is not None:
            result['anchorCategory'] = self.anchor_category

        if self.anchor_material_name is not None:
            result['anchorMaterialName'] = self.anchor_material_name

        if self.cover_url is not None:
            result['coverUrl'] = self.cover_url

        if self.digital_human_type is not None:
            result['digitalHumanType'] = self.digital_human_type

        if self.gender is not None:
            result['gender'] = self.gender

        if self.use_scene is not None:
            result['useScene'] = self.use_scene

        if self.video_oss_key is not None:
            result['videoOssKey'] = self.video_oss_key

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('anchorCategory') is not None:
            self.anchor_category = m.get('anchorCategory')

        if m.get('anchorMaterialName') is not None:
            self.anchor_material_name = m.get('anchorMaterialName')

        if m.get('coverUrl') is not None:
            self.cover_url = m.get('coverUrl')

        if m.get('digitalHumanType') is not None:
            self.digital_human_type = m.get('digitalHumanType')

        if m.get('gender') is not None:
            self.gender = m.get('gender')

        if m.get('useScene') is not None:
            self.use_scene = m.get('useScene')

        if m.get('videoOssKey') is not None:
            self.video_oss_key = m.get('videoOssKey')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class BatchGetProjectTaskRequest(DaraModel):
    def __init__(
        self,
        task_id_list: List[str] = None,
    ):
        self.task_id_list = task_id_list

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.task_id_list is not None:
            result['taskIdList'] = self.task_id_list

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('taskIdList') is not None:
            self.task_id_list = m.get('taskIdList')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class SendSdkStreamMessageRequest(DaraModel):
    def __init__(
        self,
        data: str = None,
        header: str = None,
        module_name: str = None,
        operation_name: str = None,
        user_id: str = None,
    ):
        self.data = data
        # header
        self.header = header
        self.module_name = module_name
        self.operation_name = operation_name
        self.user_id = user_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.data is not None:
            result['data'] = self.data

        if self.header is not None:
            result['header'] = self.header

        if self.module_name is not None:
            result['moduleName'] = self.module_name

        if self.operation_name is not None:
            result['operationName'] = self.operation_name

        if self.user_id is not None:
            result['userId'] = self.user_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('data') is not None:
            self.data = m.get('data')

        if m.get('header') is not None:
            self.header = m.get('header')

        if m.get('moduleName') is not None:
            self.module_name = m.get('moduleName')

        if m.get('operationName') is not None:
            self.operation_name = m.get('operationName')

        if m.get('userId') is not None:
            self.user_id = m.get('userId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class CreateVideoClipTaskRequest(DaraModel):
    def __init__(
        self,
        aliyun_main_id: str = None,
        description: str = None,
        oss_keys: List[str] = None,
        requirement: str = None,
    ):
        self.aliyun_main_id = aliyun_main_id
        self.description = description
        self.oss_keys = oss_keys
        self.requirement = requirement

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.aliyun_main_id is not None:
            result['aliyunMainId'] = self.aliyun_main_id

        if self.description is not None:
            result['description'] = self.description

        if self.oss_keys is not None:
            result['ossKeys'] = self.oss_keys

        if self.requirement is not None:
            result['requirement'] = self.requirement

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('aliyunMainId') is not None:
            self.aliyun_main_id = m.get('aliyunMainId')

        if m.get('description') is not None:
            self.description = m.get('description')

        if m.get('ossKeys') is not None:
            self.oss_keys = m.get('ossKeys')

        if m.get('requirement') is not None:
            self.requirement = m.get('requirement')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class TextTheme(DaraModel):
    def __init__(
        self,
        desc: str = None,
        name: str = None,
    ):
        self.desc = desc
        self.name = name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.desc is not None:
            result['desc'] = self.desc

        if self.name is not None:
            result['name'] = self.name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('desc') is not None:
            self.desc = m.get('desc')

        if m.get('name') is not None:
            self.name = m.get('name')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class SelectResourceResponseBody(DaraModel):
    def __init__(
        self,
        aliyun_uid: str = None,
        request_id: str = None,
        resource_info_list: List[main_models.SelectResourceResponseBodyResourceInfoList] = None,
    ):
        self.aliyun_uid = aliyun_uid
        self.request_id = request_id
        self.resource_info_list = resource_info_list

    def validate(self):
        if self.resource_info_list:
            for v1 in self.resource_info_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.aliyun_uid is not None:
            result['aliyunUid'] = self.aliyun_uid

        if self.request_id is not None:
            result['requestId'] = self.request_id

        result['resourceInfoList'] = []
        if self.resource_info_list is not None:
            for k1 in self.resource_info_list:
                result['resourceInfoList'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('aliyunUid') is not None:
            self.aliyun_uid = m.get('aliyunUid')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        self.resource_info_list = []
        if m.get('resourceInfoList') is not None:
            for k1 in m.get('resourceInfoList'):
                temp_model = main_models.SelectResourceResponseBodyResourceInfoList()
                self.resource_info_list.append(temp_model.from_map(k1))

        return self

class SelectResourceResponseBodyResourceInfoList(DaraModel):
    def __init__(
        self,
        expire_time: str = None,
        last_expire: int = None,
        remain_count: int = None,
        resource_type: int = None,
        unit: str = None,
    ):
        self.expire_time = expire_time
        self.last_expire = last_expire
        self.remain_count = remain_count
        self.resource_type = resource_type
        self.unit = unit

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.expire_time is not None:
            result['expireTime'] = self.expire_time

        if self.last_expire is not None:
            result['lastExpire'] = self.last_expire

        if self.remain_count is not None:
            result['remainCount'] = self.remain_count

        if self.resource_type is not None:
            result['resourceType'] = self.resource_type

        if self.unit is not None:
            result['unit'] = self.unit

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('expireTime') is not None:
            self.expire_time = m.get('expireTime')

        if m.get('lastExpire') is not None:
            self.last_expire = m.get('lastExpire')

        if m.get('remainCount') is not None:
            self.remain_count = m.get('remainCount')

        if m.get('resourceType') is not None:
            self.resource_type = m.get('resourceType')

        if m.get('unit') is not None:
            self.unit = m.get('unit')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class BatchGetProjectTaskResponseBody(DaraModel):
    def __init__(
        self,
        request_id: str = None,
        result_list: List[main_models.BatchGetProjectTaskResponseBodyResultList] = None,
    ):
        # Id of the request
        self.request_id = request_id
        self.result_list = result_list

    def validate(self):
        if self.result_list:
            for v1 in self.result_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.request_id is not None:
            result['requestId'] = self.request_id

        result['resultList'] = []
        if self.result_list is not None:
            for k1 in self.result_list:
                result['resultList'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        self.result_list = []
        if m.get('resultList') is not None:
            for k1 in m.get('resultList'):
                temp_model = main_models.BatchGetProjectTaskResponseBodyResultList()
                self.result_list.append(temp_model.from_map(k1))

        return self

class BatchGetProjectTaskResponseBodyResultList(DaraModel):
    def __init__(
        self,
        error_msg: str = None,
        status: str = None,
        task_id: str = None,
        video_download_url: str = None,
        video_duration: int = None,
        video_url: str = None,
    ):
        self.error_msg = error_msg
        self.status = status
        self.task_id = task_id
        self.video_download_url = video_download_url
        self.video_duration = video_duration
        self.video_url = video_url

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.error_msg is not None:
            result['errorMsg'] = self.error_msg

        if self.status is not None:
            result['status'] = self.status

        if self.task_id is not None:
            result['taskId'] = self.task_id

        if self.video_download_url is not None:
            result['videoDownloadUrl'] = self.video_download_url

        if self.video_duration is not None:
            result['videoDuration'] = self.video_duration

        if self.video_url is not None:
            result['videoUrl'] = self.video_url

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('errorMsg') is not None:
            self.error_msg = m.get('errorMsg')

        if m.get('status') is not None:
            self.status = m.get('status')

        if m.get('taskId') is not None:
            self.task_id = m.get('taskId')

        if m.get('videoDownloadUrl') is not None:
            self.video_download_url = m.get('videoDownloadUrl')

        if m.get('videoDuration') is not None:
            self.video_duration = m.get('videoDuration')

        if m.get('videoUrl') is not None:
            self.video_url = m.get('videoUrl')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class IllustrationTaskCreateCmd(DaraModel):
    def __init__(
        self,
        background_type: int = None,
        dst_height: int = None,
        dst_width: int = None,
        idempotent_id: str = None,
        image_urls: List[str] = None,
        nums: int = None,
        oss_paths: List[str] = None,
        sticker_text: str = None,
    ):
        self.background_type = background_type
        self.dst_height = dst_height
        self.dst_width = dst_width
        self.idempotent_id = idempotent_id
        self.image_urls = image_urls
        self.nums = nums
        self.oss_paths = oss_paths
        self.sticker_text = sticker_text

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.background_type is not None:
            result['backgroundType'] = self.background_type

        if self.dst_height is not None:
            result['dstHeight'] = self.dst_height

        if self.dst_width is not None:
            result['dstWidth'] = self.dst_width

        if self.idempotent_id is not None:
            result['idempotentId'] = self.idempotent_id

        if self.image_urls is not None:
            result['imageUrls'] = self.image_urls

        if self.nums is not None:
            result['nums'] = self.nums

        if self.oss_paths is not None:
            result['ossPaths'] = self.oss_paths

        if self.sticker_text is not None:
            result['stickerText'] = self.sticker_text

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('backgroundType') is not None:
            self.background_type = m.get('backgroundType')

        if m.get('dstHeight') is not None:
            self.dst_height = m.get('dstHeight')

        if m.get('dstWidth') is not None:
            self.dst_width = m.get('dstWidth')

        if m.get('idempotentId') is not None:
            self.idempotent_id = m.get('idempotentId')

        if m.get('imageUrls') is not None:
            self.image_urls = m.get('imageUrls')

        if m.get('nums') is not None:
            self.nums = m.get('nums')

        if m.get('ossPaths') is not None:
            self.oss_paths = m.get('ossPaths')

        if m.get('stickerText') is not None:
            self.sticker_text = m.get('stickerText')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List, Dict

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class ListAICoachScriptPageResponseBody(DaraModel):
    def __init__(
        self,
        error_code: str = None,
        error_message: str = None,
        list: List[main_models.ListAICoachScriptPageResponseBodyList] = None,
        request_id: str = None,
        success: bool = None,
        total: int = None,
    ):
        self.error_code = error_code
        self.error_message = error_message
        self.list = list
        # Id of the request
        self.request_id = request_id
        self.success = success
        self.total = total

    def validate(self):
        if self.list:
            for v1 in self.list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.error_code is not None:
            result['errorCode'] = self.error_code

        if self.error_message is not None:
            result['errorMessage'] = self.error_message

        result['list'] = []
        if self.list is not None:
            for k1 in self.list:
                result['list'].append(k1.to_map() if k1 else None)

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.success is not None:
            result['success'] = self.success

        if self.total is not None:
            result['total'] = self.total

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('errorCode') is not None:
            self.error_code = m.get('errorCode')

        if m.get('errorMessage') is not None:
            self.error_message = m.get('errorMessage')

        self.list = []
        if m.get('list') is not None:
            for k1 in m.get('list'):
                temp_model = main_models.ListAICoachScriptPageResponseBodyList()
                self.list.append(temp_model.from_map(k1))

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('success') is not None:
            self.success = m.get('success')

        if m.get('total') is not None:
            self.total = m.get('total')

        return self

class ListAICoachScriptPageResponseBodyList(DaraModel):
    def __init__(
        self,
        append_question_flag: str = None,
        assessment_scope: str = None,
        closing_remarks: str = None,
        complete_strategy: main_models.ListAICoachScriptPageResponseBodyListCompleteStrategy = None,
        cover_url: str = None,
        custom_reply_rules: List[main_models.ListAICoachScriptPageResponseBodyListCustomReplyRules] = None,
        dialogue_text_flag: bool = None,
        dialogue_tip_flag: bool = None,
        evaluate_report_flag: bool = None,
        expressiveness: Dict[str, str] = None,
        gif_dynamic_url: str = None,
        gif_static_url: str = None,
        gmt_create: str = None,
        gmt_modified: str = None,
        initiator: str = None,
        interaction_type: str = None,
        introduce: str = None,
        name: str = None,
        opening_remarks: str = None,
        order_ack_flag: bool = None,
        sample_dialogue_list: List[main_models.ListAICoachScriptPageResponseBodyListSampleDialogueList] = None,
        score_config: main_models.ListAICoachScriptPageResponseBodyListScoreConfig = None,
        script_record_id: str = None,
        sparring_tip_content: str = None,
        sparring_tip_title: str = None,
        status: int = None,
        student_think_time_flag: bool = None,
        type: int = None,
        weights: main_models.ListAICoachScriptPageResponseBodyListWeights = None,
    ):
        self.append_question_flag = append_question_flag
        self.assessment_scope = assessment_scope
        self.closing_remarks = closing_remarks
        self.complete_strategy = complete_strategy
        self.cover_url = cover_url
        self.custom_reply_rules = custom_reply_rules
        self.dialogue_text_flag = dialogue_text_flag
        self.dialogue_tip_flag = dialogue_tip_flag
        self.evaluate_report_flag = evaluate_report_flag
        self.expressiveness = expressiveness
        self.gif_dynamic_url = gif_dynamic_url
        self.gif_static_url = gif_static_url
        self.gmt_create = gmt_create
        self.gmt_modified = gmt_modified
        self.initiator = initiator
        self.interaction_type = interaction_type
        self.introduce = introduce
        self.name = name
        self.opening_remarks = opening_remarks
        self.order_ack_flag = order_ack_flag
        self.sample_dialogue_list = sample_dialogue_list
        self.score_config = score_config
        self.script_record_id = script_record_id
        self.sparring_tip_content = sparring_tip_content
        self.sparring_tip_title = sparring_tip_title
        self.status = status
        self.student_think_time_flag = student_think_time_flag
        self.type = type
        self.weights = weights

    def validate(self):
        if self.complete_strategy:
            self.complete_strategy.validate()
        if self.custom_reply_rules:
            for v1 in self.custom_reply_rules:
                 if v1:
                    v1.validate()
        if self.sample_dialogue_list:
            for v1 in self.sample_dialogue_list:
                 if v1:
                    v1.validate()
        if self.score_config:
            self.score_config.validate()
        if self.weights:
            self.weights.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.append_question_flag is not None:
            result['appendQuestionFlag'] = self.append_question_flag

        if self.assessment_scope is not None:
            result['assessmentScope'] = self.assessment_scope

        if self.closing_remarks is not None:
            result['closingRemarks'] = self.closing_remarks

        if self.complete_strategy is not None:
            result['completeStrategy'] = self.complete_strategy.to_map()

        if self.cover_url is not None:
            result['coverUrl'] = self.cover_url

        result['customReplyRules'] = []
        if self.custom_reply_rules is not None:
            for k1 in self.custom_reply_rules:
                result['customReplyRules'].append(k1.to_map() if k1 else None)

        if self.dialogue_text_flag is not None:
            result['dialogueTextFlag'] = self.dialogue_text_flag

        if self.dialogue_tip_flag is not None:
            result['dialogueTipFlag'] = self.dialogue_tip_flag

        if self.evaluate_report_flag is not None:
            result['evaluateReportFlag'] = self.evaluate_report_flag

        if self.expressiveness is not None:
            result['expressiveness'] = self.expressiveness

        if self.gif_dynamic_url is not None:
            result['gifDynamicUrl'] = self.gif_dynamic_url

        if self.gif_static_url is not None:
            result['gifStaticUrl'] = self.gif_static_url

        if self.gmt_create is not None:
            result['gmtCreate'] = self.gmt_create

        if self.gmt_modified is not None:
            result['gmtModified'] = self.gmt_modified

        if self.initiator is not None:
            result['initiator'] = self.initiator

        if self.interaction_type is not None:
            result['interactionType'] = self.interaction_type

        if self.introduce is not None:
            result['introduce'] = self.introduce

        if self.name is not None:
            result['name'] = self.name

        if self.opening_remarks is not None:
            result['openingRemarks'] = self.opening_remarks

        if self.order_ack_flag is not None:
            result['orderAckFlag'] = self.order_ack_flag

        result['sampleDialogueList'] = []
        if self.sample_dialogue_list is not None:
            for k1 in self.sample_dialogue_list:
                result['sampleDialogueList'].append(k1.to_map() if k1 else None)

        if self.score_config is not None:
            result['scoreConfig'] = self.score_config.to_map()

        if self.script_record_id is not None:
            result['scriptRecordId'] = self.script_record_id

        if self.sparring_tip_content is not None:
            result['sparringTipContent'] = self.sparring_tip_content

        if self.sparring_tip_title is not None:
            result['sparringTipTitle'] = self.sparring_tip_title

        if self.status is not None:
            result['status'] = self.status

        if self.student_think_time_flag is not None:
            result['studentThinkTimeFlag'] = self.student_think_time_flag

        if self.type is not None:
            result['type'] = self.type

        if self.weights is not None:
            result['weights'] = self.weights.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('appendQuestionFlag') is not None:
            self.append_question_flag = m.get('appendQuestionFlag')

        if m.get('assessmentScope') is not None:
            self.assessment_scope = m.get('assessmentScope')

        if m.get('closingRemarks') is not None:
            self.closing_remarks = m.get('closingRemarks')

        if m.get('completeStrategy') is not None:
            temp_model = main_models.ListAICoachScriptPageResponseBodyListCompleteStrategy()
            self.complete_strategy = temp_model.from_map(m.get('completeStrategy'))

        if m.get('coverUrl') is not None:
            self.cover_url = m.get('coverUrl')

        self.custom_reply_rules = []
        if m.get('customReplyRules') is not None:
            for k1 in m.get('customReplyRules'):
                temp_model = main_models.ListAICoachScriptPageResponseBodyListCustomReplyRules()
                self.custom_reply_rules.append(temp_model.from_map(k1))

        if m.get('dialogueTextFlag') is not None:
            self.dialogue_text_flag = m.get('dialogueTextFlag')

        if m.get('dialogueTipFlag') is not None:
            self.dialogue_tip_flag = m.get('dialogueTipFlag')

        if m.get('evaluateReportFlag') is not None:
            self.evaluate_report_flag = m.get('evaluateReportFlag')

        if m.get('expressiveness') is not None:
            self.expressiveness = m.get('expressiveness')

        if m.get('gifDynamicUrl') is not None:
            self.gif_dynamic_url = m.get('gifDynamicUrl')

        if m.get('gifStaticUrl') is not None:
            self.gif_static_url = m.get('gifStaticUrl')

        if m.get('gmtCreate') is not None:
            self.gmt_create = m.get('gmtCreate')

        if m.get('gmtModified') is not None:
            self.gmt_modified = m.get('gmtModified')

        if m.get('initiator') is not None:
            self.initiator = m.get('initiator')

        if m.get('interactionType') is not None:
            self.interaction_type = m.get('interactionType')

        if m.get('introduce') is not None:
            self.introduce = m.get('introduce')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('openingRemarks') is not None:
            self.opening_remarks = m.get('openingRemarks')

        if m.get('orderAckFlag') is not None:
            self.order_ack_flag = m.get('orderAckFlag')

        self.sample_dialogue_list = []
        if m.get('sampleDialogueList') is not None:
            for k1 in m.get('sampleDialogueList'):
                temp_model = main_models.ListAICoachScriptPageResponseBodyListSampleDialogueList()
                self.sample_dialogue_list.append(temp_model.from_map(k1))

        if m.get('scoreConfig') is not None:
            temp_model = main_models.ListAICoachScriptPageResponseBodyListScoreConfig()
            self.score_config = temp_model.from_map(m.get('scoreConfig'))

        if m.get('scriptRecordId') is not None:
            self.script_record_id = m.get('scriptRecordId')

        if m.get('sparringTipContent') is not None:
            self.sparring_tip_content = m.get('sparringTipContent')

        if m.get('sparringTipTitle') is not None:
            self.sparring_tip_title = m.get('sparringTipTitle')

        if m.get('status') is not None:
            self.status = m.get('status')

        if m.get('studentThinkTimeFlag') is not None:
            self.student_think_time_flag = m.get('studentThinkTimeFlag')

        if m.get('type') is not None:
            self.type = m.get('type')

        if m.get('weights') is not None:
            temp_model = main_models.ListAICoachScriptPageResponseBodyListWeights()
            self.weights = temp_model.from_map(m.get('weights'))

        return self

class ListAICoachScriptPageResponseBodyListWeights(DaraModel):
    def __init__(
        self,
        assessment_point: int = None,
        assessment_point_enabled: bool = None,
        custom_reply_rule_enabled: bool = None,
        expressiveness: int = None,
        expressiveness_enabled: bool = None,
        point_deduction_rule: int = None,
        point_deduction_rule_enabled: bool = None,
        similar_pronunciation_scoring_enabled: bool = None,
        standard: int = None,
        standard_enabled: bool = None,
    ):
        self.assessment_point = assessment_point
        self.assessment_point_enabled = assessment_point_enabled
        self.custom_reply_rule_enabled = custom_reply_rule_enabled
        self.expressiveness = expressiveness
        self.expressiveness_enabled = expressiveness_enabled
        self.point_deduction_rule = point_deduction_rule
        self.point_deduction_rule_enabled = point_deduction_rule_enabled
        self.similar_pronunciation_scoring_enabled = similar_pronunciation_scoring_enabled
        self.standard = standard
        self.standard_enabled = standard_enabled

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.assessment_point is not None:
            result['assessmentPoint'] = self.assessment_point

        if self.assessment_point_enabled is not None:
            result['assessmentPointEnabled'] = self.assessment_point_enabled

        if self.custom_reply_rule_enabled is not None:
            result['customReplyRuleEnabled'] = self.custom_reply_rule_enabled

        if self.expressiveness is not None:
            result['expressiveness'] = self.expressiveness

        if self.expressiveness_enabled is not None:
            result['expressivenessEnabled'] = self.expressiveness_enabled

        if self.point_deduction_rule is not None:
            result['pointDeductionRule'] = self.point_deduction_rule

        if self.point_deduction_rule_enabled is not None:
            result['pointDeductionRuleEnabled'] = self.point_deduction_rule_enabled

        if self.similar_pronunciation_scoring_enabled is not None:
            result['similarPronunciationScoringEnabled'] = self.similar_pronunciation_scoring_enabled

        if self.standard is not None:
            result['standard'] = self.standard

        if self.standard_enabled is not None:
            result['standardEnabled'] = self.standard_enabled

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('assessmentPoint') is not None:
            self.assessment_point = m.get('assessmentPoint')

        if m.get('assessmentPointEnabled') is not None:
            self.assessment_point_enabled = m.get('assessmentPointEnabled')

        if m.get('customReplyRuleEnabled') is not None:
            self.custom_reply_rule_enabled = m.get('customReplyRuleEnabled')

        if m.get('expressiveness') is not None:
            self.expressiveness = m.get('expressiveness')

        if m.get('expressivenessEnabled') is not None:
            self.expressiveness_enabled = m.get('expressivenessEnabled')

        if m.get('pointDeductionRule') is not None:
            self.point_deduction_rule = m.get('pointDeductionRule')

        if m.get('pointDeductionRuleEnabled') is not None:
            self.point_deduction_rule_enabled = m.get('pointDeductionRuleEnabled')

        if m.get('similarPronunciationScoringEnabled') is not None:
            self.similar_pronunciation_scoring_enabled = m.get('similarPronunciationScoringEnabled')

        if m.get('standard') is not None:
            self.standard = m.get('standard')

        if m.get('standardEnabled') is not None:
            self.standard_enabled = m.get('standardEnabled')

        return self

class ListAICoachScriptPageResponseBodyListScoreConfig(DaraModel):
    def __init__(
        self,
        enabled: bool = None,
        level_enabled: bool = None,
        levels: List[main_models.ListAICoachScriptPageResponseBodyListScoreConfigLevels] = None,
        pass_score: int = None,
    ):
        self.enabled = enabled
        self.level_enabled = level_enabled
        self.levels = levels
        self.pass_score = pass_score

    def validate(self):
        if self.levels:
            for v1 in self.levels:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.enabled is not None:
            result['enabled'] = self.enabled

        if self.level_enabled is not None:
            result['levelEnabled'] = self.level_enabled

        result['levels'] = []
        if self.levels is not None:
            for k1 in self.levels:
                result['levels'].append(k1.to_map() if k1 else None)

        if self.pass_score is not None:
            result['passScore'] = self.pass_score

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('enabled') is not None:
            self.enabled = m.get('enabled')

        if m.get('levelEnabled') is not None:
            self.level_enabled = m.get('levelEnabled')

        self.levels = []
        if m.get('levels') is not None:
            for k1 in m.get('levels'):
                temp_model = main_models.ListAICoachScriptPageResponseBodyListScoreConfigLevels()
                self.levels.append(temp_model.from_map(k1))

        if m.get('passScore') is not None:
            self.pass_score = m.get('passScore')

        return self

class ListAICoachScriptPageResponseBodyListScoreConfigLevels(DaraModel):
    def __init__(
        self,
        max: int = None,
        min: int = None,
        name: str = None,
    ):
        self.max = max
        self.min = min
        self.name = name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.max is not None:
            result['max'] = self.max

        if self.min is not None:
            result['min'] = self.min

        if self.name is not None:
            result['name'] = self.name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('max') is not None:
            self.max = m.get('max')

        if m.get('min') is not None:
            self.min = m.get('min')

        if m.get('name') is not None:
            self.name = m.get('name')

        return self

class ListAICoachScriptPageResponseBodyListSampleDialogueList(DaraModel):
    def __init__(
        self,
        message: str = None,
        role: str = None,
    ):
        self.message = message
        self.role = role

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.message is not None:
            result['message'] = self.message

        if self.role is not None:
            result['role'] = self.role

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('message') is not None:
            self.message = m.get('message')

        if m.get('role') is not None:
            self.role = m.get('role')

        return self

class ListAICoachScriptPageResponseBodyListCustomReplyRules(DaraModel):
    def __init__(
        self,
        action: main_models.ListAICoachScriptPageResponseBodyListCustomReplyRulesAction = None,
        logic: str = None,
        main_condition: main_models.ListAICoachScriptPageResponseBodyListCustomReplyRulesMainCondition = None,
        priority: int = None,
        sort_no: int = None,
        sub_condition: main_models.ListAICoachScriptPageResponseBodyListCustomReplyRulesSubCondition = None,
    ):
        self.action = action
        self.logic = logic
        self.main_condition = main_condition
        self.priority = priority
        self.sort_no = sort_no
        self.sub_condition = sub_condition

    def validate(self):
        if self.action:
            self.action.validate()
        if self.main_condition:
            self.main_condition.validate()
        if self.sub_condition:
            self.sub_condition.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.action is not None:
            result['action'] = self.action.to_map()

        if self.logic is not None:
            result['logic'] = self.logic

        if self.main_condition is not None:
            result['mainCondition'] = self.main_condition.to_map()

        if self.priority is not None:
            result['priority'] = self.priority

        if self.sort_no is not None:
            result['sortNo'] = self.sort_no

        if self.sub_condition is not None:
            result['subCondition'] = self.sub_condition.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('action') is not None:
            temp_model = main_models.ListAICoachScriptPageResponseBodyListCustomReplyRulesAction()
            self.action = temp_model.from_map(m.get('action'))

        if m.get('logic') is not None:
            self.logic = m.get('logic')

        if m.get('mainCondition') is not None:
            temp_model = main_models.ListAICoachScriptPageResponseBodyListCustomReplyRulesMainCondition()
            self.main_condition = temp_model.from_map(m.get('mainCondition'))

        if m.get('priority') is not None:
            self.priority = m.get('priority')

        if m.get('sortNo') is not None:
            self.sort_no = m.get('sortNo')

        if m.get('subCondition') is not None:
            temp_model = main_models.ListAICoachScriptPageResponseBodyListCustomReplyRulesSubCondition()
            self.sub_condition = temp_model.from_map(m.get('subCondition'))

        return self

class ListAICoachScriptPageResponseBodyListCustomReplyRulesSubCondition(DaraModel):
    def __init__(
        self,
        type: str = None,
    ):
        self.type = type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.type is not None:
            result['type'] = self.type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('type') is not None:
            self.type = m.get('type')

        return self

class ListAICoachScriptPageResponseBodyListCustomReplyRulesMainCondition(DaraModel):
    def __init__(
        self,
        parameters: main_models.ListAICoachScriptPageResponseBodyListCustomReplyRulesMainConditionParameters = None,
        type: str = None,
    ):
        self.parameters = parameters
        self.type = type

    def validate(self):
        if self.parameters:
            self.parameters.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.parameters is not None:
            result['parameters'] = self.parameters.to_map()

        if self.type is not None:
            result['type'] = self.type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('parameters') is not None:
            temp_model = main_models.ListAICoachScriptPageResponseBodyListCustomReplyRulesMainConditionParameters()
            self.parameters = temp_model.from_map(m.get('parameters'))

        if m.get('type') is not None:
            self.type = m.get('type')

        return self

class ListAICoachScriptPageResponseBodyListCustomReplyRulesMainConditionParameters(DaraModel):
    def __init__(
        self,
        assess_point: str = None,
    ):
        self.assess_point = assess_point

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.assess_point is not None:
            result['assessPoint'] = self.assess_point

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('assessPoint') is not None:
            self.assess_point = m.get('assessPoint')

        return self

class ListAICoachScriptPageResponseBodyListCustomReplyRulesAction(DaraModel):
    def __init__(
        self,
        parameters: main_models.ListAICoachScriptPageResponseBodyListCustomReplyRulesActionParameters = None,
        type: str = None,
    ):
        self.parameters = parameters
        self.type = type

    def validate(self):
        if self.parameters:
            self.parameters.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.parameters is not None:
            result['parameters'] = self.parameters.to_map()

        if self.type is not None:
            result['type'] = self.type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('parameters') is not None:
            temp_model = main_models.ListAICoachScriptPageResponseBodyListCustomReplyRulesActionParameters()
            self.parameters = temp_model.from_map(m.get('parameters'))

        if m.get('type') is not None:
            self.type = m.get('type')

        return self

class ListAICoachScriptPageResponseBodyListCustomReplyRulesActionParameters(DaraModel):
    def __init__(
        self,
        assess_point: str = None,
        custom_content: str = None,
    ):
        self.assess_point = assess_point
        self.custom_content = custom_content

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.assess_point is not None:
            result['assessPoint'] = self.assess_point

        if self.custom_content is not None:
            result['customContent'] = self.custom_content

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('assessPoint') is not None:
            self.assess_point = m.get('assessPoint')

        if m.get('customContent') is not None:
            self.custom_content = m.get('customContent')

        return self

class ListAICoachScriptPageResponseBodyListCompleteStrategy(DaraModel):
    def __init__(
        self,
        click_complete_auto_end: bool = None,
        duration: int = None,
        full_coverage_auto_end: bool = None,
    ):
        self.click_complete_auto_end = click_complete_auto_end
        self.duration = duration
        self.full_coverage_auto_end = full_coverage_auto_end

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.click_complete_auto_end is not None:
            result['clickCompleteAutoEnd'] = self.click_complete_auto_end

        if self.duration is not None:
            result['duration'] = self.duration

        if self.full_coverage_auto_end is not None:
            result['fullCoverageAutoEnd'] = self.full_coverage_auto_end

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('clickCompleteAutoEnd') is not None:
            self.click_complete_auto_end = m.get('clickCompleteAutoEnd')

        if m.get('duration') is not None:
            self.duration = m.get('duration')

        if m.get('fullCoverageAutoEnd') is not None:
            self.full_coverage_auto_end = m.get('fullCoverageAutoEnd')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class TransferPortraitStyleRequest(DaraModel):
    def __init__(
        self,
        height: int = None,
        image_url: str = None,
        numbers: int = None,
        redraw_amplitude: int = None,
        style: int = None,
        width: int = None,
    ):
        self.height = height
        self.image_url = image_url
        self.numbers = numbers
        self.redraw_amplitude = redraw_amplitude
        self.style = style
        self.width = width

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.height is not None:
            result['height'] = self.height

        if self.image_url is not None:
            result['imageUrl'] = self.image_url

        if self.numbers is not None:
            result['numbers'] = self.numbers

        if self.redraw_amplitude is not None:
            result['redrawAmplitude'] = self.redraw_amplitude

        if self.style is not None:
            result['style'] = self.style

        if self.width is not None:
            result['width'] = self.width

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('height') is not None:
            self.height = m.get('height')

        if m.get('imageUrl') is not None:
            self.image_url = m.get('imageUrl')

        if m.get('numbers') is not None:
            self.numbers = m.get('numbers')

        if m.get('redrawAmplitude') is not None:
            self.redraw_amplitude = m.get('redrawAmplitude')

        if m.get('style') is not None:
            self.style = m.get('style')

        if m.get('width') is not None:
            self.width = m.get('width')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class GetAICoachAssessmentPointResponseBody(DaraModel):
    def __init__(
        self,
        answer_list: List[main_models.GetAICoachAssessmentPointResponseBodyAnswerList] = None,
        citations: int = None,
        document_id: str = None,
        document_name: str = None,
        gmt_create: str = None,
        gmt_modified: str = None,
        kb_id: str = None,
        kb_type: str = None,
        knowledge_list: List[str] = None,
        name: str = None,
        point_id: str = None,
        question_description: str = None,
        question_sample: str = None,
        request_id: str = None,
        status: str = None,
    ):
        self.answer_list = answer_list
        self.citations = citations
        self.document_id = document_id
        self.document_name = document_name
        self.gmt_create = gmt_create
        self.gmt_modified = gmt_modified
        self.kb_id = kb_id
        self.kb_type = kb_type
        self.knowledge_list = knowledge_list
        self.name = name
        self.point_id = point_id
        self.question_description = question_description
        self.question_sample = question_sample
        # Id of the request
        self.request_id = request_id
        self.status = status

    def validate(self):
        if self.answer_list:
            for v1 in self.answer_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['answerList'] = []
        if self.answer_list is not None:
            for k1 in self.answer_list:
                result['answerList'].append(k1.to_map() if k1 else None)

        if self.citations is not None:
            result['citations'] = self.citations

        if self.document_id is not None:
            result['documentId'] = self.document_id

        if self.document_name is not None:
            result['documentName'] = self.document_name

        if self.gmt_create is not None:
            result['gmtCreate'] = self.gmt_create

        if self.gmt_modified is not None:
            result['gmtModified'] = self.gmt_modified

        if self.kb_id is not None:
            result['kbId'] = self.kb_id

        if self.kb_type is not None:
            result['kbType'] = self.kb_type

        if self.knowledge_list is not None:
            result['knowledgeList'] = self.knowledge_list

        if self.name is not None:
            result['name'] = self.name

        if self.point_id is not None:
            result['pointId'] = self.point_id

        if self.question_description is not None:
            result['questionDescription'] = self.question_description

        if self.question_sample is not None:
            result['questionSample'] = self.question_sample

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.status is not None:
            result['status'] = self.status

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.answer_list = []
        if m.get('answerList') is not None:
            for k1 in m.get('answerList'):
                temp_model = main_models.GetAICoachAssessmentPointResponseBodyAnswerList()
                self.answer_list.append(temp_model.from_map(k1))

        if m.get('citations') is not None:
            self.citations = m.get('citations')

        if m.get('documentId') is not None:
            self.document_id = m.get('documentId')

        if m.get('documentName') is not None:
            self.document_name = m.get('documentName')

        if m.get('gmtCreate') is not None:
            self.gmt_create = m.get('gmtCreate')

        if m.get('gmtModified') is not None:
            self.gmt_modified = m.get('gmtModified')

        if m.get('kbId') is not None:
            self.kb_id = m.get('kbId')

        if m.get('kbType') is not None:
            self.kb_type = m.get('kbType')

        if m.get('knowledgeList') is not None:
            self.knowledge_list = m.get('knowledgeList')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('pointId') is not None:
            self.point_id = m.get('pointId')

        if m.get('questionDescription') is not None:
            self.question_description = m.get('questionDescription')

        if m.get('questionSample') is not None:
            self.question_sample = m.get('questionSample')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('status') is not None:
            self.status = m.get('status')

        return self

class GetAICoachAssessmentPointResponseBodyAnswerList(DaraModel):
    def __init__(
        self,
        answer_values: List[main_models.GetAICoachAssessmentPointResponseBodyAnswerListAnswerValues] = None,
        enabled_keyword: bool = None,
        name_list: List[str] = None,
        operators: str = None,
        parameters: List[main_models.GetAICoachAssessmentPointResponseBodyAnswerListParameters] = None,
        type: str = None,
        weight: int = None,
    ):
        self.answer_values = answer_values
        self.enabled_keyword = enabled_keyword
        self.name_list = name_list
        self.operators = operators
        self.parameters = parameters
        self.type = type
        self.weight = weight

    def validate(self):
        if self.answer_values:
            for v1 in self.answer_values:
                 if v1:
                    v1.validate()
        if self.parameters:
            for v1 in self.parameters:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['answerValues'] = []
        if self.answer_values is not None:
            for k1 in self.answer_values:
                result['answerValues'].append(k1.to_map() if k1 else None)

        if self.enabled_keyword is not None:
            result['enabledKeyword'] = self.enabled_keyword

        if self.name_list is not None:
            result['nameList'] = self.name_list

        if self.operators is not None:
            result['operators'] = self.operators

        result['parameters'] = []
        if self.parameters is not None:
            for k1 in self.parameters:
                result['parameters'].append(k1.to_map() if k1 else None)

        if self.type is not None:
            result['type'] = self.type

        if self.weight is not None:
            result['weight'] = self.weight

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.answer_values = []
        if m.get('answerValues') is not None:
            for k1 in m.get('answerValues'):
                temp_model = main_models.GetAICoachAssessmentPointResponseBodyAnswerListAnswerValues()
                self.answer_values.append(temp_model.from_map(k1))

        if m.get('enabledKeyword') is not None:
            self.enabled_keyword = m.get('enabledKeyword')

        if m.get('nameList') is not None:
            self.name_list = m.get('nameList')

        if m.get('operators') is not None:
            self.operators = m.get('operators')

        self.parameters = []
        if m.get('parameters') is not None:
            for k1 in m.get('parameters'):
                temp_model = main_models.GetAICoachAssessmentPointResponseBodyAnswerListParameters()
                self.parameters.append(temp_model.from_map(k1))

        if m.get('type') is not None:
            self.type = m.get('type')

        if m.get('weight') is not None:
            self.weight = m.get('weight')

        return self

class GetAICoachAssessmentPointResponseBodyAnswerListParameters(DaraModel):
    def __init__(
        self,
        name: str = None,
        value: str = None,
    ):
        self.name = name
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.name is not None:
            result['name'] = self.name

        if self.value is not None:
            result['value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('value') is not None:
            self.value = m.get('value')

        return self

class GetAICoachAssessmentPointResponseBodyAnswerListAnswerValues(DaraModel):
    def __init__(
        self,
        answer_name: str = None,
        answer_weight: int = None,
        keyword_values: List[main_models.GetAICoachAssessmentPointResponseBodyAnswerListAnswerValuesKeywordValues] = None,
        keyword_weight: int = None,
        scoring_rules: List[main_models.GetAICoachAssessmentPointResponseBodyAnswerListAnswerValuesScoringRules] = None,
    ):
        self.answer_name = answer_name
        self.answer_weight = answer_weight
        self.keyword_values = keyword_values
        self.keyword_weight = keyword_weight
        self.scoring_rules = scoring_rules

    def validate(self):
        if self.keyword_values:
            for v1 in self.keyword_values:
                 if v1:
                    v1.validate()
        if self.scoring_rules:
            for v1 in self.scoring_rules:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.answer_name is not None:
            result['answerName'] = self.answer_name

        if self.answer_weight is not None:
            result['answerWeight'] = self.answer_weight

        result['keywordValues'] = []
        if self.keyword_values is not None:
            for k1 in self.keyword_values:
                result['keywordValues'].append(k1.to_map() if k1 else None)

        if self.keyword_weight is not None:
            result['keywordWeight'] = self.keyword_weight

        result['scoringRules'] = []
        if self.scoring_rules is not None:
            for k1 in self.scoring_rules:
                result['scoringRules'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('answerName') is not None:
            self.answer_name = m.get('answerName')

        if m.get('answerWeight') is not None:
            self.answer_weight = m.get('answerWeight')

        self.keyword_values = []
        if m.get('keywordValues') is not None:
            for k1 in m.get('keywordValues'):
                temp_model = main_models.GetAICoachAssessmentPointResponseBodyAnswerListAnswerValuesKeywordValues()
                self.keyword_values.append(temp_model.from_map(k1))

        if m.get('keywordWeight') is not None:
            self.keyword_weight = m.get('keywordWeight')

        self.scoring_rules = []
        if m.get('scoringRules') is not None:
            for k1 in m.get('scoringRules'):
                temp_model = main_models.GetAICoachAssessmentPointResponseBodyAnswerListAnswerValuesScoringRules()
                self.scoring_rules.append(temp_model.from_map(k1))

        return self

class GetAICoachAssessmentPointResponseBodyAnswerListAnswerValuesScoringRules(DaraModel):
    def __init__(
        self,
        name: str = None,
    ):
        self.name = name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.name is not None:
            result['name'] = self.name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('name') is not None:
            self.name = m.get('name')

        return self

class GetAICoachAssessmentPointResponseBodyAnswerListAnswerValuesKeywordValues(DaraModel):
    def __init__(
        self,
        name: str = None,
        weight: int = None,
    ):
        self.name = name
        self.weight = weight

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.name is not None:
            result['name'] = self.name

        if self.weight is not None:
            result['weight'] = self.weight

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('weight') is not None:
            self.weight = m.get('weight')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ReferenceTag(DaraModel):
    def __init__(
        self,
        reference_content: str = None,
        reference_title: str = None,
    ):
        self.reference_content = reference_content
        self.reference_title = reference_title

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.reference_content is not None:
            result['referenceContent'] = self.reference_content

        if self.reference_title is not None:
            result['referenceTitle'] = self.reference_title

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('referenceContent') is not None:
            self.reference_content = m.get('referenceContent')

        if m.get('referenceTitle') is not None:
            self.reference_title = m.get('referenceTitle')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class SubmitImageToVideoTaskRequest(DaraModel):
    def __init__(
        self,
        image_url: str = None,
        pos_prompt: str = None,
    ):
        self.image_url = image_url
        self.pos_prompt = pos_prompt

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.image_url is not None:
            result['imageUrl'] = self.image_url

        if self.pos_prompt is not None:
            result['posPrompt'] = self.pos_prompt

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('imageUrl') is not None:
            self.image_url = m.get('imageUrl')

        if m.get('posPrompt') is not None:
            self.pos_prompt = m.get('posPrompt')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ListVoiceModelsRequest(DaraModel):
    def __init__(
        self,
        page_number: int = None,
        page_size: int = None,
        res_spec_type: str = None,
        use_scene: str = None,
        voice_language: str = None,
        voice_type: str = None,
    ):
        self.page_number = page_number
        self.page_size = page_size
        self.res_spec_type = res_spec_type
        self.use_scene = use_scene
        self.voice_language = voice_language
        self.voice_type = voice_type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.page_number is not None:
            result['pageNumber'] = self.page_number

        if self.page_size is not None:
            result['pageSize'] = self.page_size

        if self.res_spec_type is not None:
            result['resSpecType'] = self.res_spec_type

        if self.use_scene is not None:
            result['useScene'] = self.use_scene

        if self.voice_language is not None:
            result['voiceLanguage'] = self.voice_language

        if self.voice_type is not None:
            result['voiceType'] = self.voice_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('pageNumber') is not None:
            self.page_number = m.get('pageNumber')

        if m.get('pageSize') is not None:
            self.page_size = m.get('pageSize')

        if m.get('resSpecType') is not None:
            self.res_spec_type = m.get('resSpecType')

        if m.get('useScene') is not None:
            self.use_scene = m.get('useScene')

        if m.get('voiceLanguage') is not None:
            self.voice_language = m.get('voiceLanguage')

        if m.get('voiceType') is not None:
            self.voice_type = m.get('voiceType')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List, Dict

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class GetAICoachScriptResponseBody(DaraModel):
    def __init__(
        self,
        agent_id: str = None,
        append_question_flag: bool = None,
        assessment_scope: str = None,
        check_cheat_config: main_models.GetAICoachScriptResponseBodyCheckCheatConfig = None,
        closing_remarks: str = None,
        complete_strategy: main_models.GetAICoachScriptResponseBodyCompleteStrategy = None,
        cover_url: str = None,
        custom_reply_rules: List[main_models.GetAICoachScriptResponseBodyCustomReplyRules] = None,
        dialogue_input_text_limit: int = None,
        dialogue_text_flag: bool = None,
        dialogue_tip_flag: bool = None,
        dialogue_voice_limit: int = None,
        evaluate_report_flag: bool = None,
        expressiveness: Dict[str, int] = None,
        expressiveness_list: List[main_models.GetAICoachScriptResponseBodyExpressivenessList] = None,
        gif_dynamic_url: str = None,
        gif_static_url: str = None,
        gmt_create: str = None,
        gmt_modified: str = None,
        initiator: str = None,
        interaction_input_types: List[str] = None,
        interaction_type: int = None,
        introduce: str = None,
        name: str = None,
        opening_remarks: str = None,
        order_ack_flag: bool = None,
        point_deduction_rule_list: List[main_models.GetAICoachScriptResponseBodyPointDeductionRuleList] = None,
        points: List[main_models.GetAICoachScriptResponseBodyPoints] = None,
        request_id: str = None,
        sample_dialogue_list: List[main_models.GetAICoachScriptResponseBodySampleDialogueList] = None,
        score_config: main_models.GetAICoachScriptResponseBodyScoreConfig = None,
        script_record_id: str = None,
        sparring_tip_content: str = None,
        sparring_tip_title: str = None,
        status: int = None,
        student_think_time_flag: bool = None,
        student_think_time_limit: int = None,
        type: int = None,
        voice_id: str = None,
        voice_language: str = None,
        weights: main_models.GetAICoachScriptResponseBodyWeights = None,
    ):
        self.agent_id = agent_id
        self.append_question_flag = append_question_flag
        self.assessment_scope = assessment_scope
        self.check_cheat_config = check_cheat_config
        self.closing_remarks = closing_remarks
        self.complete_strategy = complete_strategy
        self.cover_url = cover_url
        self.custom_reply_rules = custom_reply_rules
        self.dialogue_input_text_limit = dialogue_input_text_limit
        self.dialogue_text_flag = dialogue_text_flag
        self.dialogue_tip_flag = dialogue_tip_flag
        self.dialogue_voice_limit = dialogue_voice_limit
        self.evaluate_report_flag = evaluate_report_flag
        self.expressiveness = expressiveness
        self.expressiveness_list = expressiveness_list
        self.gif_dynamic_url = gif_dynamic_url
        self.gif_static_url = gif_static_url
        self.gmt_create = gmt_create
        self.gmt_modified = gmt_modified
        self.initiator = initiator
        self.interaction_input_types = interaction_input_types
        self.interaction_type = interaction_type
        self.introduce = introduce
        self.name = name
        self.opening_remarks = opening_remarks
        self.order_ack_flag = order_ack_flag
        self.point_deduction_rule_list = point_deduction_rule_list
        self.points = points
        self.request_id = request_id
        self.sample_dialogue_list = sample_dialogue_list
        self.score_config = score_config
        self.script_record_id = script_record_id
        self.sparring_tip_content = sparring_tip_content
        self.sparring_tip_title = sparring_tip_title
        self.status = status
        self.student_think_time_flag = student_think_time_flag
        self.student_think_time_limit = student_think_time_limit
        self.type = type
        self.voice_id = voice_id
        self.voice_language = voice_language
        self.weights = weights

    def validate(self):
        if self.check_cheat_config:
            self.check_cheat_config.validate()
        if self.complete_strategy:
            self.complete_strategy.validate()
        if self.custom_reply_rules:
            for v1 in self.custom_reply_rules:
                 if v1:
                    v1.validate()
        if self.expressiveness_list:
            for v1 in self.expressiveness_list:
                 if v1:
                    v1.validate()
        if self.point_deduction_rule_list:
            for v1 in self.point_deduction_rule_list:
                 if v1:
                    v1.validate()
        if self.points:
            for v1 in self.points:
                 if v1:
                    v1.validate()
        if self.sample_dialogue_list:
            for v1 in self.sample_dialogue_list:
                 if v1:
                    v1.validate()
        if self.score_config:
            self.score_config.validate()
        if self.weights:
            self.weights.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.agent_id is not None:
            result['agentId'] = self.agent_id

        if self.append_question_flag is not None:
            result['appendQuestionFlag'] = self.append_question_flag

        if self.assessment_scope is not None:
            result['assessmentScope'] = self.assessment_scope

        if self.check_cheat_config is not None:
            result['checkCheatConfig'] = self.check_cheat_config.to_map()

        if self.closing_remarks is not None:
            result['closingRemarks'] = self.closing_remarks

        if self.complete_strategy is not None:
            result['completeStrategy'] = self.complete_strategy.to_map()

        if self.cover_url is not None:
            result['coverUrl'] = self.cover_url

        result['customReplyRules'] = []
        if self.custom_reply_rules is not None:
            for k1 in self.custom_reply_rules:
                result['customReplyRules'].append(k1.to_map() if k1 else None)

        if self.dialogue_input_text_limit is not None:
            result['dialogueInputTextLimit'] = self.dialogue_input_text_limit

        if self.dialogue_text_flag is not None:
            result['dialogueTextFlag'] = self.dialogue_text_flag

        if self.dialogue_tip_flag is not None:
            result['dialogueTipFlag'] = self.dialogue_tip_flag

        if self.dialogue_voice_limit is not None:
            result['dialogueVoiceLimit'] = self.dialogue_voice_limit

        if self.evaluate_report_flag is not None:
            result['evaluateReportFlag'] = self.evaluate_report_flag

        if self.expressiveness is not None:
            result['expressiveness'] = self.expressiveness

        result['expressivenessList'] = []
        if self.expressiveness_list is not None:
            for k1 in self.expressiveness_list:
                result['expressivenessList'].append(k1.to_map() if k1 else None)

        if self.gif_dynamic_url is not None:
            result['gifDynamicUrl'] = self.gif_dynamic_url

        if self.gif_static_url is not None:
            result['gifStaticUrl'] = self.gif_static_url

        if self.gmt_create is not None:
            result['gmtCreate'] = self.gmt_create

        if self.gmt_modified is not None:
            result['gmtModified'] = self.gmt_modified

        if self.initiator is not None:
            result['initiator'] = self.initiator

        if self.interaction_input_types is not None:
            result['interactionInputTypes'] = self.interaction_input_types

        if self.interaction_type is not None:
            result['interactionType'] = self.interaction_type

        if self.introduce is not None:
            result['introduce'] = self.introduce

        if self.name is not None:
            result['name'] = self.name

        if self.opening_remarks is not None:
            result['openingRemarks'] = self.opening_remarks

        if self.order_ack_flag is not None:
            result['orderAckFlag'] = self.order_ack_flag

        result['pointDeductionRuleList'] = []
        if self.point_deduction_rule_list is not None:
            for k1 in self.point_deduction_rule_list:
                result['pointDeductionRuleList'].append(k1.to_map() if k1 else None)

        result['points'] = []
        if self.points is not None:
            for k1 in self.points:
                result['points'].append(k1.to_map() if k1 else None)

        if self.request_id is not None:
            result['requestId'] = self.request_id

        result['sampleDialogueList'] = []
        if self.sample_dialogue_list is not None:
            for k1 in self.sample_dialogue_list:
                result['sampleDialogueList'].append(k1.to_map() if k1 else None)

        if self.score_config is not None:
            result['scoreConfig'] = self.score_config.to_map()

        if self.script_record_id is not None:
            result['scriptRecordId'] = self.script_record_id

        if self.sparring_tip_content is not None:
            result['sparringTipContent'] = self.sparring_tip_content

        if self.sparring_tip_title is not None:
            result['sparringTipTitle'] = self.sparring_tip_title

        if self.status is not None:
            result['status'] = self.status

        if self.student_think_time_flag is not None:
            result['studentThinkTimeFlag'] = self.student_think_time_flag

        if self.student_think_time_limit is not None:
            result['studentThinkTimeLimit'] = self.student_think_time_limit

        if self.type is not None:
            result['type'] = self.type

        if self.voice_id is not None:
            result['voiceId'] = self.voice_id

        if self.voice_language is not None:
            result['voiceLanguage'] = self.voice_language

        if self.weights is not None:
            result['weights'] = self.weights.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('agentId') is not None:
            self.agent_id = m.get('agentId')

        if m.get('appendQuestionFlag') is not None:
            self.append_question_flag = m.get('appendQuestionFlag')

        if m.get('assessmentScope') is not None:
            self.assessment_scope = m.get('assessmentScope')

        if m.get('checkCheatConfig') is not None:
            temp_model = main_models.GetAICoachScriptResponseBodyCheckCheatConfig()
            self.check_cheat_config = temp_model.from_map(m.get('checkCheatConfig'))

        if m.get('closingRemarks') is not None:
            self.closing_remarks = m.get('closingRemarks')

        if m.get('completeStrategy') is not None:
            temp_model = main_models.GetAICoachScriptResponseBodyCompleteStrategy()
            self.complete_strategy = temp_model.from_map(m.get('completeStrategy'))

        if m.get('coverUrl') is not None:
            self.cover_url = m.get('coverUrl')

        self.custom_reply_rules = []
        if m.get('customReplyRules') is not None:
            for k1 in m.get('customReplyRules'):
                temp_model = main_models.GetAICoachScriptResponseBodyCustomReplyRules()
                self.custom_reply_rules.append(temp_model.from_map(k1))

        if m.get('dialogueInputTextLimit') is not None:
            self.dialogue_input_text_limit = m.get('dialogueInputTextLimit')

        if m.get('dialogueTextFlag') is not None:
            self.dialogue_text_flag = m.get('dialogueTextFlag')

        if m.get('dialogueTipFlag') is not None:
            self.dialogue_tip_flag = m.get('dialogueTipFlag')

        if m.get('dialogueVoiceLimit') is not None:
            self.dialogue_voice_limit = m.get('dialogueVoiceLimit')

        if m.get('evaluateReportFlag') is not None:
            self.evaluate_report_flag = m.get('evaluateReportFlag')

        if m.get('expressiveness') is not None:
            self.expressiveness = m.get('expressiveness')

        self.expressiveness_list = []
        if m.get('expressivenessList') is not None:
            for k1 in m.get('expressivenessList'):
                temp_model = main_models.GetAICoachScriptResponseBodyExpressivenessList()
                self.expressiveness_list.append(temp_model.from_map(k1))

        if m.get('gifDynamicUrl') is not None:
            self.gif_dynamic_url = m.get('gifDynamicUrl')

        if m.get('gifStaticUrl') is not None:
            self.gif_static_url = m.get('gifStaticUrl')

        if m.get('gmtCreate') is not None:
            self.gmt_create = m.get('gmtCreate')

        if m.get('gmtModified') is not None:
            self.gmt_modified = m.get('gmtModified')

        if m.get('initiator') is not None:
            self.initiator = m.get('initiator')

        if m.get('interactionInputTypes') is not None:
            self.interaction_input_types = m.get('interactionInputTypes')

        if m.get('interactionType') is not None:
            self.interaction_type = m.get('interactionType')

        if m.get('introduce') is not None:
            self.introduce = m.get('introduce')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('openingRemarks') is not None:
            self.opening_remarks = m.get('openingRemarks')

        if m.get('orderAckFlag') is not None:
            self.order_ack_flag = m.get('orderAckFlag')

        self.point_deduction_rule_list = []
        if m.get('pointDeductionRuleList') is not None:
            for k1 in m.get('pointDeductionRuleList'):
                temp_model = main_models.GetAICoachScriptResponseBodyPointDeductionRuleList()
                self.point_deduction_rule_list.append(temp_model.from_map(k1))

        self.points = []
        if m.get('points') is not None:
            for k1 in m.get('points'):
                temp_model = main_models.GetAICoachScriptResponseBodyPoints()
                self.points.append(temp_model.from_map(k1))

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        self.sample_dialogue_list = []
        if m.get('sampleDialogueList') is not None:
            for k1 in m.get('sampleDialogueList'):
                temp_model = main_models.GetAICoachScriptResponseBodySampleDialogueList()
                self.sample_dialogue_list.append(temp_model.from_map(k1))

        if m.get('scoreConfig') is not None:
            temp_model = main_models.GetAICoachScriptResponseBodyScoreConfig()
            self.score_config = temp_model.from_map(m.get('scoreConfig'))

        if m.get('scriptRecordId') is not None:
            self.script_record_id = m.get('scriptRecordId')

        if m.get('sparringTipContent') is not None:
            self.sparring_tip_content = m.get('sparringTipContent')

        if m.get('sparringTipTitle') is not None:
            self.sparring_tip_title = m.get('sparringTipTitle')

        if m.get('status') is not None:
            self.status = m.get('status')

        if m.get('studentThinkTimeFlag') is not None:
            self.student_think_time_flag = m.get('studentThinkTimeFlag')

        if m.get('studentThinkTimeLimit') is not None:
            self.student_think_time_limit = m.get('studentThinkTimeLimit')

        if m.get('type') is not None:
            self.type = m.get('type')

        if m.get('voiceId') is not None:
            self.voice_id = m.get('voiceId')

        if m.get('voiceLanguage') is not None:
            self.voice_language = m.get('voiceLanguage')

        if m.get('weights') is not None:
            temp_model = main_models.GetAICoachScriptResponseBodyWeights()
            self.weights = temp_model.from_map(m.get('weights'))

        return self

class GetAICoachScriptResponseBodyWeights(DaraModel):
    def __init__(
        self,
        ability_evaluation: int = None,
        ability_evaluation_enabled: bool = None,
        assessment_point: int = None,
        assessment_point_enabled: bool = None,
        custom_reply_rule_enabled: bool = None,
        expressiveness: int = None,
        expressiveness_enabled: bool = None,
        point_deduction_rule: int = None,
        point_deduction_rule_enabled: bool = None,
        similar_pronunciation_scoring_enabled: bool = None,
        standard: int = None,
        standard_enabled: bool = None,
    ):
        self.ability_evaluation = ability_evaluation
        self.ability_evaluation_enabled = ability_evaluation_enabled
        self.assessment_point = assessment_point
        self.assessment_point_enabled = assessment_point_enabled
        self.custom_reply_rule_enabled = custom_reply_rule_enabled
        self.expressiveness = expressiveness
        self.expressiveness_enabled = expressiveness_enabled
        self.point_deduction_rule = point_deduction_rule
        self.point_deduction_rule_enabled = point_deduction_rule_enabled
        self.similar_pronunciation_scoring_enabled = similar_pronunciation_scoring_enabled
        self.standard = standard
        self.standard_enabled = standard_enabled

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.ability_evaluation is not None:
            result['abilityEvaluation'] = self.ability_evaluation

        if self.ability_evaluation_enabled is not None:
            result['abilityEvaluationEnabled'] = self.ability_evaluation_enabled

        if self.assessment_point is not None:
            result['assessmentPoint'] = self.assessment_point

        if self.assessment_point_enabled is not None:
            result['assessmentPointEnabled'] = self.assessment_point_enabled

        if self.custom_reply_rule_enabled is not None:
            result['customReplyRuleEnabled'] = self.custom_reply_rule_enabled

        if self.expressiveness is not None:
            result['expressiveness'] = self.expressiveness

        if self.expressiveness_enabled is not None:
            result['expressivenessEnabled'] = self.expressiveness_enabled

        if self.point_deduction_rule is not None:
            result['pointDeductionRule'] = self.point_deduction_rule

        if self.point_deduction_rule_enabled is not None:
            result['pointDeductionRuleEnabled'] = self.point_deduction_rule_enabled

        if self.similar_pronunciation_scoring_enabled is not None:
            result['similarPronunciationScoringEnabled'] = self.similar_pronunciation_scoring_enabled

        if self.standard is not None:
            result['standard'] = self.standard

        if self.standard_enabled is not None:
            result['standardEnabled'] = self.standard_enabled

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('abilityEvaluation') is not None:
            self.ability_evaluation = m.get('abilityEvaluation')

        if m.get('abilityEvaluationEnabled') is not None:
            self.ability_evaluation_enabled = m.get('abilityEvaluationEnabled')

        if m.get('assessmentPoint') is not None:
            self.assessment_point = m.get('assessmentPoint')

        if m.get('assessmentPointEnabled') is not None:
            self.assessment_point_enabled = m.get('assessmentPointEnabled')

        if m.get('customReplyRuleEnabled') is not None:
            self.custom_reply_rule_enabled = m.get('customReplyRuleEnabled')

        if m.get('expressiveness') is not None:
            self.expressiveness = m.get('expressiveness')

        if m.get('expressivenessEnabled') is not None:
            self.expressiveness_enabled = m.get('expressivenessEnabled')

        if m.get('pointDeductionRule') is not None:
            self.point_deduction_rule = m.get('pointDeductionRule')

        if m.get('pointDeductionRuleEnabled') is not None:
            self.point_deduction_rule_enabled = m.get('pointDeductionRuleEnabled')

        if m.get('similarPronunciationScoringEnabled') is not None:
            self.similar_pronunciation_scoring_enabled = m.get('similarPronunciationScoringEnabled')

        if m.get('standard') is not None:
            self.standard = m.get('standard')

        if m.get('standardEnabled') is not None:
            self.standard_enabled = m.get('standardEnabled')

        return self

class GetAICoachScriptResponseBodyScoreConfig(DaraModel):
    def __init__(
        self,
        enabled: bool = None,
        level_enabled: bool = None,
        levels: List[main_models.GetAICoachScriptResponseBodyScoreConfigLevels] = None,
        pass_score: str = None,
    ):
        self.enabled = enabled
        self.level_enabled = level_enabled
        self.levels = levels
        self.pass_score = pass_score

    def validate(self):
        if self.levels:
            for v1 in self.levels:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.enabled is not None:
            result['enabled'] = self.enabled

        if self.level_enabled is not None:
            result['levelEnabled'] = self.level_enabled

        result['levels'] = []
        if self.levels is not None:
            for k1 in self.levels:
                result['levels'].append(k1.to_map() if k1 else None)

        if self.pass_score is not None:
            result['passScore'] = self.pass_score

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('enabled') is not None:
            self.enabled = m.get('enabled')

        if m.get('levelEnabled') is not None:
            self.level_enabled = m.get('levelEnabled')

        self.levels = []
        if m.get('levels') is not None:
            for k1 in m.get('levels'):
                temp_model = main_models.GetAICoachScriptResponseBodyScoreConfigLevels()
                self.levels.append(temp_model.from_map(k1))

        if m.get('passScore') is not None:
            self.pass_score = m.get('passScore')

        return self

class GetAICoachScriptResponseBodyScoreConfigLevels(DaraModel):
    def __init__(
        self,
        max: int = None,
        min: int = None,
        name: str = None,
    ):
        self.max = max
        self.min = min
        self.name = name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.max is not None:
            result['max'] = self.max

        if self.min is not None:
            result['min'] = self.min

        if self.name is not None:
            result['name'] = self.name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('max') is not None:
            self.max = m.get('max')

        if m.get('min') is not None:
            self.min = m.get('min')

        if m.get('name') is not None:
            self.name = m.get('name')

        return self

class GetAICoachScriptResponseBodySampleDialogueList(DaraModel):
    def __init__(
        self,
        message: str = None,
        role: str = None,
    ):
        self.message = message
        self.role = role

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.message is not None:
            result['message'] = self.message

        if self.role is not None:
            result['role'] = self.role

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('message') is not None:
            self.message = m.get('message')

        if m.get('role') is not None:
            self.role = m.get('role')

        return self

class GetAICoachScriptResponseBodyPoints(DaraModel):
    def __init__(
        self,
        answer_list: List[main_models.GetAICoachScriptResponseBodyPointsAnswerList] = None,
        knowledge_list: List[str] = None,
        name: str = None,
        point_id: str = None,
        question_description: str = None,
        sort_no: int = None,
        weight: int = None,
    ):
        self.answer_list = answer_list
        self.knowledge_list = knowledge_list
        self.name = name
        self.point_id = point_id
        self.question_description = question_description
        self.sort_no = sort_no
        self.weight = weight

    def validate(self):
        if self.answer_list:
            for v1 in self.answer_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['answerList'] = []
        if self.answer_list is not None:
            for k1 in self.answer_list:
                result['answerList'].append(k1.to_map() if k1 else None)

        if self.knowledge_list is not None:
            result['knowledgeList'] = self.knowledge_list

        if self.name is not None:
            result['name'] = self.name

        if self.point_id is not None:
            result['pointId'] = self.point_id

        if self.question_description is not None:
            result['questionDescription'] = self.question_description

        if self.sort_no is not None:
            result['sortNo'] = self.sort_no

        if self.weight is not None:
            result['weight'] = self.weight

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.answer_list = []
        if m.get('answerList') is not None:
            for k1 in m.get('answerList'):
                temp_model = main_models.GetAICoachScriptResponseBodyPointsAnswerList()
                self.answer_list.append(temp_model.from_map(k1))

        if m.get('knowledgeList') is not None:
            self.knowledge_list = m.get('knowledgeList')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('pointId') is not None:
            self.point_id = m.get('pointId')

        if m.get('questionDescription') is not None:
            self.question_description = m.get('questionDescription')

        if m.get('sortNo') is not None:
            self.sort_no = m.get('sortNo')

        if m.get('weight') is not None:
            self.weight = m.get('weight')

        return self

class GetAICoachScriptResponseBodyPointsAnswerList(DaraModel):
    def __init__(
        self,
        answer_values: List[main_models.GetAICoachScriptResponseBodyPointsAnswerListAnswerValues] = None,
        enabled_keyword: bool = None,
        name: str = None,
        name_list: List[str] = None,
        operators: str = None,
        parameters: List[main_models.GetAICoachScriptResponseBodyPointsAnswerListParameters] = None,
        type: str = None,
        weight: int = None,
    ):
        self.answer_values = answer_values
        self.enabled_keyword = enabled_keyword
        self.name = name
        self.name_list = name_list
        self.operators = operators
        self.parameters = parameters
        self.type = type
        self.weight = weight

    def validate(self):
        if self.answer_values:
            for v1 in self.answer_values:
                 if v1:
                    v1.validate()
        if self.parameters:
            for v1 in self.parameters:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['answerValues'] = []
        if self.answer_values is not None:
            for k1 in self.answer_values:
                result['answerValues'].append(k1.to_map() if k1 else None)

        if self.enabled_keyword is not None:
            result['enabledKeyword'] = self.enabled_keyword

        if self.name is not None:
            result['name'] = self.name

        if self.name_list is not None:
            result['nameList'] = self.name_list

        if self.operators is not None:
            result['operators'] = self.operators

        result['parameters'] = []
        if self.parameters is not None:
            for k1 in self.parameters:
                result['parameters'].append(k1.to_map() if k1 else None)

        if self.type is not None:
            result['type'] = self.type

        if self.weight is not None:
            result['weight'] = self.weight

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.answer_values = []
        if m.get('answerValues') is not None:
            for k1 in m.get('answerValues'):
                temp_model = main_models.GetAICoachScriptResponseBodyPointsAnswerListAnswerValues()
                self.answer_values.append(temp_model.from_map(k1))

        if m.get('enabledKeyword') is not None:
            self.enabled_keyword = m.get('enabledKeyword')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('nameList') is not None:
            self.name_list = m.get('nameList')

        if m.get('operators') is not None:
            self.operators = m.get('operators')

        self.parameters = []
        if m.get('parameters') is not None:
            for k1 in m.get('parameters'):
                temp_model = main_models.GetAICoachScriptResponseBodyPointsAnswerListParameters()
                self.parameters.append(temp_model.from_map(k1))

        if m.get('type') is not None:
            self.type = m.get('type')

        if m.get('weight') is not None:
            self.weight = m.get('weight')

        return self

class GetAICoachScriptResponseBodyPointsAnswerListParameters(DaraModel):
    def __init__(
        self,
        name: str = None,
        value: str = None,
    ):
        self.name = name
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.name is not None:
            result['name'] = self.name

        if self.value is not None:
            result['value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('value') is not None:
            self.value = m.get('value')

        return self

class GetAICoachScriptResponseBodyPointsAnswerListAnswerValues(DaraModel):
    def __init__(
        self,
        answer_name: str = None,
        answer_weight: int = None,
        keyword_values: List[main_models.GetAICoachScriptResponseBodyPointsAnswerListAnswerValuesKeywordValues] = None,
        keyword_weight: int = None,
        scoring_rules: List[main_models.GetAICoachScriptResponseBodyPointsAnswerListAnswerValuesScoringRules] = None,
    ):
        self.answer_name = answer_name
        self.answer_weight = answer_weight
        self.keyword_values = keyword_values
        self.keyword_weight = keyword_weight
        self.scoring_rules = scoring_rules

    def validate(self):
        if self.keyword_values:
            for v1 in self.keyword_values:
                 if v1:
                    v1.validate()
        if self.scoring_rules:
            for v1 in self.scoring_rules:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.answer_name is not None:
            result['answerName'] = self.answer_name

        if self.answer_weight is not None:
            result['answerWeight'] = self.answer_weight

        result['keywordValues'] = []
        if self.keyword_values is not None:
            for k1 in self.keyword_values:
                result['keywordValues'].append(k1.to_map() if k1 else None)

        if self.keyword_weight is not None:
            result['keywordWeight'] = self.keyword_weight

        result['scoringRules'] = []
        if self.scoring_rules is not None:
            for k1 in self.scoring_rules:
                result['scoringRules'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('answerName') is not None:
            self.answer_name = m.get('answerName')

        if m.get('answerWeight') is not None:
            self.answer_weight = m.get('answerWeight')

        self.keyword_values = []
        if m.get('keywordValues') is not None:
            for k1 in m.get('keywordValues'):
                temp_model = main_models.GetAICoachScriptResponseBodyPointsAnswerListAnswerValuesKeywordValues()
                self.keyword_values.append(temp_model.from_map(k1))

        if m.get('keywordWeight') is not None:
            self.keyword_weight = m.get('keywordWeight')

        self.scoring_rules = []
        if m.get('scoringRules') is not None:
            for k1 in m.get('scoringRules'):
                temp_model = main_models.GetAICoachScriptResponseBodyPointsAnswerListAnswerValuesScoringRules()
                self.scoring_rules.append(temp_model.from_map(k1))

        return self

class GetAICoachScriptResponseBodyPointsAnswerListAnswerValuesScoringRules(DaraModel):
    def __init__(
        self,
        name: str = None,
    ):
        self.name = name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.name is not None:
            result['name'] = self.name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('name') is not None:
            self.name = m.get('name')

        return self

class GetAICoachScriptResponseBodyPointsAnswerListAnswerValuesKeywordValues(DaraModel):
    def __init__(
        self,
        name: str = None,
        weight: int = None,
    ):
        self.name = name
        self.weight = weight

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.name is not None:
            result['name'] = self.name

        if self.weight is not None:
            result['weight'] = self.weight

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('weight') is not None:
            self.weight = m.get('weight')

        return self

class GetAICoachScriptResponseBodyPointDeductionRuleList(DaraModel):
    def __init__(
        self,
        description: str = None,
        punishment_types: List[str] = None,
        rule_value: str = None,
        weight: int = None,
    ):
        self.description = description
        self.punishment_types = punishment_types
        self.rule_value = rule_value
        self.weight = weight

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.description is not None:
            result['description'] = self.description

        if self.punishment_types is not None:
            result['punishmentTypes'] = self.punishment_types

        if self.rule_value is not None:
            result['ruleValue'] = self.rule_value

        if self.weight is not None:
            result['weight'] = self.weight

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('description') is not None:
            self.description = m.get('description')

        if m.get('punishmentTypes') is not None:
            self.punishment_types = m.get('punishmentTypes')

        if m.get('ruleValue') is not None:
            self.rule_value = m.get('ruleValue')

        if m.get('weight') is not None:
            self.weight = m.get('weight')

        return self

class GetAICoachScriptResponseBodyExpressivenessList(DaraModel):
    def __init__(
        self,
        desc: str = None,
        enabled: bool = None,
        expressiveness_id: str = None,
        name: str = None,
        rule: str = None,
        type: str = None,
        weight: int = None,
    ):
        self.desc = desc
        self.enabled = enabled
        self.expressiveness_id = expressiveness_id
        self.name = name
        self.rule = rule
        self.type = type
        self.weight = weight

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.desc is not None:
            result['desc'] = self.desc

        if self.enabled is not None:
            result['enabled'] = self.enabled

        if self.expressiveness_id is not None:
            result['expressivenessId'] = self.expressiveness_id

        if self.name is not None:
            result['name'] = self.name

        if self.rule is not None:
            result['rule'] = self.rule

        if self.type is not None:
            result['type'] = self.type

        if self.weight is not None:
            result['weight'] = self.weight

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('desc') is not None:
            self.desc = m.get('desc')

        if m.get('enabled') is not None:
            self.enabled = m.get('enabled')

        if m.get('expressivenessId') is not None:
            self.expressiveness_id = m.get('expressivenessId')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('rule') is not None:
            self.rule = m.get('rule')

        if m.get('type') is not None:
            self.type = m.get('type')

        if m.get('weight') is not None:
            self.weight = m.get('weight')

        return self

class GetAICoachScriptResponseBodyCustomReplyRules(DaraModel):
    def __init__(
        self,
        action: main_models.GetAICoachScriptResponseBodyCustomReplyRulesAction = None,
        logic: str = None,
        main_condition: main_models.GetAICoachScriptResponseBodyCustomReplyRulesMainCondition = None,
        priority: int = None,
        sub_condition: main_models.GetAICoachScriptResponseBodyCustomReplyRulesSubCondition = None,
    ):
        self.action = action
        self.logic = logic
        self.main_condition = main_condition
        self.priority = priority
        self.sub_condition = sub_condition

    def validate(self):
        if self.action:
            self.action.validate()
        if self.main_condition:
            self.main_condition.validate()
        if self.sub_condition:
            self.sub_condition.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.action is not None:
            result['action'] = self.action.to_map()

        if self.logic is not None:
            result['logic'] = self.logic

        if self.main_condition is not None:
            result['mainCondition'] = self.main_condition.to_map()

        if self.priority is not None:
            result['priority'] = self.priority

        if self.sub_condition is not None:
            result['subCondition'] = self.sub_condition.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('action') is not None:
            temp_model = main_models.GetAICoachScriptResponseBodyCustomReplyRulesAction()
            self.action = temp_model.from_map(m.get('action'))

        if m.get('logic') is not None:
            self.logic = m.get('logic')

        if m.get('mainCondition') is not None:
            temp_model = main_models.GetAICoachScriptResponseBodyCustomReplyRulesMainCondition()
            self.main_condition = temp_model.from_map(m.get('mainCondition'))

        if m.get('priority') is not None:
            self.priority = m.get('priority')

        if m.get('subCondition') is not None:
            temp_model = main_models.GetAICoachScriptResponseBodyCustomReplyRulesSubCondition()
            self.sub_condition = temp_model.from_map(m.get('subCondition'))

        return self

class GetAICoachScriptResponseBodyCustomReplyRulesSubCondition(DaraModel):
    def __init__(
        self,
        type: str = None,
    ):
        self.type = type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.type is not None:
            result['type'] = self.type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('type') is not None:
            self.type = m.get('type')

        return self

class GetAICoachScriptResponseBodyCustomReplyRulesMainCondition(DaraModel):
    def __init__(
        self,
        parameters: main_models.GetAICoachScriptResponseBodyCustomReplyRulesMainConditionParameters = None,
        type: str = None,
    ):
        self.parameters = parameters
        self.type = type

    def validate(self):
        if self.parameters:
            self.parameters.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.parameters is not None:
            result['parameters'] = self.parameters.to_map()

        if self.type is not None:
            result['type'] = self.type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('parameters') is not None:
            temp_model = main_models.GetAICoachScriptResponseBodyCustomReplyRulesMainConditionParameters()
            self.parameters = temp_model.from_map(m.get('parameters'))

        if m.get('type') is not None:
            self.type = m.get('type')

        return self

class GetAICoachScriptResponseBodyCustomReplyRulesMainConditionParameters(DaraModel):
    def __init__(
        self,
        assess_point_id: str = None,
    ):
        self.assess_point_id = assess_point_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.assess_point_id is not None:
            result['assessPointId'] = self.assess_point_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('assessPointId') is not None:
            self.assess_point_id = m.get('assessPointId')

        return self

class GetAICoachScriptResponseBodyCustomReplyRulesAction(DaraModel):
    def __init__(
        self,
        parameters: main_models.GetAICoachScriptResponseBodyCustomReplyRulesActionParameters = None,
        type: str = None,
    ):
        self.parameters = parameters
        self.type = type

    def validate(self):
        if self.parameters:
            self.parameters.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.parameters is not None:
            result['parameters'] = self.parameters.to_map()

        if self.type is not None:
            result['type'] = self.type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('parameters') is not None:
            temp_model = main_models.GetAICoachScriptResponseBodyCustomReplyRulesActionParameters()
            self.parameters = temp_model.from_map(m.get('parameters'))

        if m.get('type') is not None:
            self.type = m.get('type')

        return self

class GetAICoachScriptResponseBodyCustomReplyRulesActionParameters(DaraModel):
    def __init__(
        self,
        assess_point_id: str = None,
        custom_content: str = None,
    ):
        self.assess_point_id = assess_point_id
        self.custom_content = custom_content

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.assess_point_id is not None:
            result['assessPointId'] = self.assess_point_id

        if self.custom_content is not None:
            result['customContent'] = self.custom_content

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('assessPointId') is not None:
            self.assess_point_id = m.get('assessPointId')

        if m.get('customContent') is not None:
            self.custom_content = m.get('customContent')

        return self

class GetAICoachScriptResponseBodyCompleteStrategy(DaraModel):
    def __init__(
        self,
        abnormal_quit_session_expired: int = None,
        abnormal_quit_session_expired_flag: bool = None,
        click_complete_auto_end: bool = None,
        duration: int = None,
        duration_flag: bool = None,
        full_coverage_auto_end: bool = None,
    ):
        self.abnormal_quit_session_expired = abnormal_quit_session_expired
        self.abnormal_quit_session_expired_flag = abnormal_quit_session_expired_flag
        self.click_complete_auto_end = click_complete_auto_end
        self.duration = duration
        self.duration_flag = duration_flag
        self.full_coverage_auto_end = full_coverage_auto_end

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.abnormal_quit_session_expired is not None:
            result['abnormalQuitSessionExpired'] = self.abnormal_quit_session_expired

        if self.abnormal_quit_session_expired_flag is not None:
            result['abnormalQuitSessionExpiredFlag'] = self.abnormal_quit_session_expired_flag

        if self.click_complete_auto_end is not None:
            result['clickCompleteAutoEnd'] = self.click_complete_auto_end

        if self.duration is not None:
            result['duration'] = self.duration

        if self.duration_flag is not None:
            result['durationFlag'] = self.duration_flag

        if self.full_coverage_auto_end is not None:
            result['fullCoverageAutoEnd'] = self.full_coverage_auto_end

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('abnormalQuitSessionExpired') is not None:
            self.abnormal_quit_session_expired = m.get('abnormalQuitSessionExpired')

        if m.get('abnormalQuitSessionExpiredFlag') is not None:
            self.abnormal_quit_session_expired_flag = m.get('abnormalQuitSessionExpiredFlag')

        if m.get('clickCompleteAutoEnd') is not None:
            self.click_complete_auto_end = m.get('clickCompleteAutoEnd')

        if m.get('duration') is not None:
            self.duration = m.get('duration')

        if m.get('durationFlag') is not None:
            self.duration_flag = m.get('durationFlag')

        if m.get('fullCoverageAutoEnd') is not None:
            self.full_coverage_auto_end = m.get('fullCoverageAutoEnd')

        return self

class GetAICoachScriptResponseBodyCheckCheatConfig(DaraModel):
    def __init__(
        self,
        check_image: bool = None,
        check_voice: bool = None,
    ):
        self.check_image = check_image
        self.check_voice = check_voice

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.check_image is not None:
            result['checkImage'] = self.check_image

        if self.check_voice is not None:
            result['checkVoice'] = self.check_voice

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('checkImage') is not None:
            self.check_image = m.get('checkImage')

        if m.get('checkVoice') is not None:
            self.check_voice = m.get('checkVoice')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class UploadInfo(DaraModel):
    def __init__(
        self,
        access_id: str = None,
        host: str = None,
        key: str = None,
        policy: str = None,
        policy_signature: str = None,
        url: str = None,
    ):
        # This parameter is required.
        self.access_id = access_id
        # This parameter is required.
        self.host = host
        # This parameter is required.
        self.key = key
        # This parameter is required.
        self.policy = policy
        # This parameter is required.
        self.policy_signature = policy_signature
        self.url = url

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.access_id is not None:
            result['accessId'] = self.access_id

        if self.host is not None:
            result['host'] = self.host

        if self.key is not None:
            result['key'] = self.key

        if self.policy is not None:
            result['policy'] = self.policy

        if self.policy_signature is not None:
            result['policySignature'] = self.policy_signature

        if self.url is not None:
            result['url'] = self.url

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('accessId') is not None:
            self.access_id = m.get('accessId')

        if m.get('host') is not None:
            self.host = m.get('host')

        if m.get('key') is not None:
            self.key = m.get('key')

        if m.get('policy') is not None:
            self.policy = m.get('policy')

        if m.get('policySignature') is not None:
            self.policy_signature = m.get('policySignature')

        if m.get('url') is not None:
            self.url = m.get('url')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class SubmitProjectTaskRequest(DaraModel):
    def __init__(
        self,
        frames: List[main_models.SubmitProjectTaskRequestFrames] = None,
        scale_type: str = None,
        subtitle_tag: int = None,
        transparent_background: int = None,
    ):
        # frame
        self.frames = frames
        self.scale_type = scale_type
        self.subtitle_tag = subtitle_tag
        self.transparent_background = transparent_background

    def validate(self):
        if self.frames:
            for v1 in self.frames:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['frames'] = []
        if self.frames is not None:
            for k1 in self.frames:
                result['frames'].append(k1.to_map() if k1 else None)

        if self.scale_type is not None:
            result['scaleType'] = self.scale_type

        if self.subtitle_tag is not None:
            result['subtitleTag'] = self.subtitle_tag

        if self.transparent_background is not None:
            result['transparentBackground'] = self.transparent_background

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.frames = []
        if m.get('frames') is not None:
            for k1 in m.get('frames'):
                temp_model = main_models.SubmitProjectTaskRequestFrames()
                self.frames.append(temp_model.from_map(k1))

        if m.get('scaleType') is not None:
            self.scale_type = m.get('scaleType')

        if m.get('subtitleTag') is not None:
            self.subtitle_tag = m.get('subtitleTag')

        if m.get('transparentBackground') is not None:
            self.transparent_background = m.get('transparentBackground')

        return self

class SubmitProjectTaskRequestFrames(DaraModel):
    def __init__(
        self,
        index: int = None,
        layers: List[main_models.SubmitProjectTaskRequestFramesLayers] = None,
        subtitle: main_models.SubmitProjectTaskRequestFramesSubtitle = None,
        video_script: main_models.SubmitProjectTaskRequestFramesVideoScript = None,
    ):
        self.index = index
        self.layers = layers
        self.subtitle = subtitle
        self.video_script = video_script

    def validate(self):
        if self.layers:
            for v1 in self.layers:
                 if v1:
                    v1.validate()
        if self.subtitle:
            self.subtitle.validate()
        if self.video_script:
            self.video_script.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.index is not None:
            result['index'] = self.index

        result['layers'] = []
        if self.layers is not None:
            for k1 in self.layers:
                result['layers'].append(k1.to_map() if k1 else None)

        if self.subtitle is not None:
            result['subtitle'] = self.subtitle.to_map()

        if self.video_script is not None:
            result['videoScript'] = self.video_script.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('index') is not None:
            self.index = m.get('index')

        self.layers = []
        if m.get('layers') is not None:
            for k1 in m.get('layers'):
                temp_model = main_models.SubmitProjectTaskRequestFramesLayers()
                self.layers.append(temp_model.from_map(k1))

        if m.get('subtitle') is not None:
            temp_model = main_models.SubmitProjectTaskRequestFramesSubtitle()
            self.subtitle = temp_model.from_map(m.get('subtitle'))

        if m.get('videoScript') is not None:
            temp_model = main_models.SubmitProjectTaskRequestFramesVideoScript()
            self.video_script = temp_model.from_map(m.get('videoScript'))

        return self

class SubmitProjectTaskRequestFramesVideoScript(DaraModel):
    def __init__(
        self,
        audio_url: str = None,
        emotion: str = None,
        pitch_rate: str = None,
        speech_open: bool = None,
        speed_rate: str = None,
        text_content: str = None,
        type: str = None,
        voice_language: str = None,
        voice_template_id: int = None,
        volume: int = None,
    ):
        self.audio_url = audio_url
        self.emotion = emotion
        self.pitch_rate = pitch_rate
        self.speech_open = speech_open
        self.speed_rate = speed_rate
        self.text_content = text_content
        self.type = type
        self.voice_language = voice_language
        self.voice_template_id = voice_template_id
        self.volume = volume

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.audio_url is not None:
            result['audioUrl'] = self.audio_url

        if self.emotion is not None:
            result['emotion'] = self.emotion

        if self.pitch_rate is not None:
            result['pitchRate'] = self.pitch_rate

        if self.speech_open is not None:
            result['speechOpen'] = self.speech_open

        if self.speed_rate is not None:
            result['speedRate'] = self.speed_rate

        if self.text_content is not None:
            result['textContent'] = self.text_content

        if self.type is not None:
            result['type'] = self.type

        if self.voice_language is not None:
            result['voiceLanguage'] = self.voice_language

        if self.voice_template_id is not None:
            result['voiceTemplateId'] = self.voice_template_id

        if self.volume is not None:
            result['volume'] = self.volume

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('audioUrl') is not None:
            self.audio_url = m.get('audioUrl')

        if m.get('emotion') is not None:
            self.emotion = m.get('emotion')

        if m.get('pitchRate') is not None:
            self.pitch_rate = m.get('pitchRate')

        if m.get('speechOpen') is not None:
            self.speech_open = m.get('speechOpen')

        if m.get('speedRate') is not None:
            self.speed_rate = m.get('speedRate')

        if m.get('textContent') is not None:
            self.text_content = m.get('textContent')

        if m.get('type') is not None:
            self.type = m.get('type')

        if m.get('voiceLanguage') is not None:
            self.voice_language = m.get('voiceLanguage')

        if m.get('voiceTemplateId') is not None:
            self.voice_template_id = m.get('voiceTemplateId')

        if m.get('volume') is not None:
            self.volume = m.get('volume')

        return self

class SubmitProjectTaskRequestFramesSubtitle(DaraModel):
    def __init__(
        self,
        alignment: str = None,
        background_color: str = None,
        font: str = None,
        font_color: str = None,
        font_size: int = None,
        max_char_length: int = None,
        position_x: int = None,
        position_y: int = None,
        text_height: int = None,
        text_width: int = None,
    ):
        self.alignment = alignment
        self.background_color = background_color
        self.font = font
        self.font_color = font_color
        self.font_size = font_size
        self.max_char_length = max_char_length
        self.position_x = position_x
        self.position_y = position_y
        self.text_height = text_height
        self.text_width = text_width

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.alignment is not None:
            result['alignment'] = self.alignment

        if self.background_color is not None:
            result['backgroundColor'] = self.background_color

        if self.font is not None:
            result['font'] = self.font

        if self.font_color is not None:
            result['fontColor'] = self.font_color

        if self.font_size is not None:
            result['fontSize'] = self.font_size

        if self.max_char_length is not None:
            result['maxCharLength'] = self.max_char_length

        if self.position_x is not None:
            result['positionX'] = self.position_x

        if self.position_y is not None:
            result['positionY'] = self.position_y

        if self.text_height is not None:
            result['textHeight'] = self.text_height

        if self.text_width is not None:
            result['textWidth'] = self.text_width

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('alignment') is not None:
            self.alignment = m.get('alignment')

        if m.get('backgroundColor') is not None:
            self.background_color = m.get('backgroundColor')

        if m.get('font') is not None:
            self.font = m.get('font')

        if m.get('fontColor') is not None:
            self.font_color = m.get('fontColor')

        if m.get('fontSize') is not None:
            self.font_size = m.get('fontSize')

        if m.get('maxCharLength') is not None:
            self.max_char_length = m.get('maxCharLength')

        if m.get('positionX') is not None:
            self.position_x = m.get('positionX')

        if m.get('positionY') is not None:
            self.position_y = m.get('positionY')

        if m.get('textHeight') is not None:
            self.text_height = m.get('textHeight')

        if m.get('textWidth') is not None:
            self.text_width = m.get('textWidth')

        return self

class SubmitProjectTaskRequestFramesLayers(DaraModel):
    def __init__(
        self,
        height: int = None,
        index: int = None,
        material: main_models.SubmitProjectTaskRequestFramesLayersMaterial = None,
        position_x: int = None,
        position_y: int = None,
        type: str = None,
        width: int = None,
    ):
        self.height = height
        self.index = index
        self.material = material
        self.position_x = position_x
        self.position_y = position_y
        self.type = type
        self.width = width

    def validate(self):
        if self.material:
            self.material.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.height is not None:
            result['height'] = self.height

        if self.index is not None:
            result['index'] = self.index

        if self.material is not None:
            result['material'] = self.material.to_map()

        if self.position_x is not None:
            result['positionX'] = self.position_x

        if self.position_y is not None:
            result['positionY'] = self.position_y

        if self.type is not None:
            result['type'] = self.type

        if self.width is not None:
            result['width'] = self.width

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('height') is not None:
            self.height = m.get('height')

        if m.get('index') is not None:
            self.index = m.get('index')

        if m.get('material') is not None:
            temp_model = main_models.SubmitProjectTaskRequestFramesLayersMaterial()
            self.material = temp_model.from_map(m.get('material'))

        if m.get('positionX') is not None:
            self.position_x = m.get('positionX')

        if m.get('positionY') is not None:
            self.position_y = m.get('positionY')

        if m.get('type') is not None:
            self.type = m.get('type')

        if m.get('width') is not None:
            self.width = m.get('width')

        return self

class SubmitProjectTaskRequestFramesLayersMaterial(DaraModel):
    def __init__(
        self,
        anchor_style_level: str = None,
        format: str = None,
        id: str = None,
        mask: main_models.SubmitProjectTaskRequestFramesLayersMaterialMask = None,
        speed: str = None,
        url: str = None,
        volume: int = None,
    ):
        self.anchor_style_level = anchor_style_level
        self.format = format
        self.id = id
        self.mask = mask
        self.speed = speed
        self.url = url
        self.volume = volume

    def validate(self):
        if self.mask:
            self.mask.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.anchor_style_level is not None:
            result['anchorStyleLevel'] = self.anchor_style_level

        if self.format is not None:
            result['format'] = self.format

        if self.id is not None:
            result['id'] = self.id

        if self.mask is not None:
            result['mask'] = self.mask.to_map()

        if self.speed is not None:
            result['speed'] = self.speed

        if self.url is not None:
            result['url'] = self.url

        if self.volume is not None:
            result['volume'] = self.volume

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('anchorStyleLevel') is not None:
            self.anchor_style_level = m.get('anchorStyleLevel')

        if m.get('format') is not None:
            self.format = m.get('format')

        if m.get('id') is not None:
            self.id = m.get('id')

        if m.get('mask') is not None:
            temp_model = main_models.SubmitProjectTaskRequestFramesLayersMaterialMask()
            self.mask = temp_model.from_map(m.get('mask'))

        if m.get('speed') is not None:
            self.speed = m.get('speed')

        if m.get('url') is not None:
            self.url = m.get('url')

        if m.get('volume') is not None:
            self.volume = m.get('volume')

        return self

class SubmitProjectTaskRequestFramesLayersMaterialMask(DaraModel):
    def __init__(
        self,
        url: str = None,
    ):
        self.url = url

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.url is not None:
            result['url'] = self.url

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('url') is not None:
            self.url = m.get('url')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class CreateIndividuationProjectRequest(DaraModel):
    def __init__(
        self,
        project_info: str = None,
        project_name: str = None,
        purpose: str = None,
        scene_id: str = None,
    ):
        self.project_info = project_info
        self.project_name = project_name
        self.purpose = purpose
        self.scene_id = scene_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.project_info is not None:
            result['projectInfo'] = self.project_info

        if self.project_name is not None:
            result['projectName'] = self.project_name

        if self.purpose is not None:
            result['purpose'] = self.purpose

        if self.scene_id is not None:
            result['sceneId'] = self.scene_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('projectInfo') is not None:
            self.project_info = m.get('projectInfo')

        if m.get('projectName') is not None:
            self.project_name = m.get('projectName')

        if m.get('purpose') is not None:
            self.purpose = m.get('purpose')

        if m.get('sceneId') is not None:
            self.scene_id = m.get('sceneId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class CreateIndividuationTextTaskRequest(DaraModel):
    def __init__(
        self,
        crowd_pack: List[List[str]] = None,
        project_id: str = None,
        task_name: str = None,
    ):
        self.crowd_pack = crowd_pack
        self.project_id = project_id
        self.task_name = task_name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.crowd_pack is not None:
            result['crowdPack'] = self.crowd_pack

        if self.project_id is not None:
            result['projectId'] = self.project_id

        if self.task_name is not None:
            result['taskName'] = self.task_name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('crowdPack') is not None:
            self.crowd_pack = m.get('crowdPack')

        if m.get('projectId') is not None:
            self.project_id = m.get('projectId')

        if m.get('taskName') is not None:
            self.task_name = m.get('taskName')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ListAICoachTaskPageRequest(DaraModel):
    def __init__(
        self,
        end_time: str = None,
        page_number: int = None,
        page_size: int = None,
        start_time: str = None,
        status: str = None,
        student_id: str = None,
        task_id: str = None,
    ):
        self.end_time = end_time
        self.page_number = page_number
        self.page_size = page_size
        self.start_time = start_time
        self.status = status
        self.student_id = student_id
        self.task_id = task_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.end_time is not None:
            result['endTime'] = self.end_time

        if self.page_number is not None:
            result['pageNumber'] = self.page_number

        if self.page_size is not None:
            result['pageSize'] = self.page_size

        if self.start_time is not None:
            result['startTime'] = self.start_time

        if self.status is not None:
            result['status'] = self.status

        if self.student_id is not None:
            result['studentId'] = self.student_id

        if self.task_id is not None:
            result['taskId'] = self.task_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('endTime') is not None:
            self.end_time = m.get('endTime')

        if m.get('pageNumber') is not None:
            self.page_number = m.get('pageNumber')

        if m.get('pageSize') is not None:
            self.page_size = m.get('pageSize')

        if m.get('startTime') is not None:
            self.start_time = m.get('startTime')

        if m.get('status') is not None:
            self.status = m.get('status')

        if m.get('studentId') is not None:
            self.student_id = m.get('studentId')

        if m.get('taskId') is not None:
            self.task_id = m.get('taskId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class DocumentResult(DaraModel):
    def __init__(
        self,
        document_info: main_models.DocumentInfo = None,
        request_id: str = None,
    ):
        self.document_info = document_info
        self.request_id = request_id

    def validate(self):
        if self.document_info:
            self.document_info.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.document_info is not None:
            result['documentInfo'] = self.document_info.to_map()

        if self.request_id is not None:
            result['requestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('documentInfo') is not None:
            temp_model = main_models.DocumentInfo()
            self.document_info = temp_model.from_map(m.get('documentInfo'))

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class CreateIllustrationTaskRequest(DaraModel):
    def __init__(
        self,
        body: main_models.IllustrationTaskCreateCmd = None,
    ):
        self.body = body

    def validate(self):
        if self.body:
            self.body.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.body is not None:
            result['body'] = self.body.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('body') is not None:
            temp_model = main_models.IllustrationTaskCreateCmd()
            self.body = temp_model.from_map(m.get('body'))

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class BatchQueryIndividuationTextResponseBody(DaraModel):
    def __init__(
        self,
        request_id: str = None,
        text_list: List[main_models.BatchQueryIndividuationTextResponseBodyTextList] = None,
    ):
        # Id of the request
        self.request_id = request_id
        self.text_list = text_list

    def validate(self):
        if self.text_list:
            for v1 in self.text_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.request_id is not None:
            result['requestId'] = self.request_id

        result['textList'] = []
        if self.text_list is not None:
            for k1 in self.text_list:
                result['textList'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        self.text_list = []
        if m.get('textList') is not None:
            for k1 in m.get('textList'):
                temp_model = main_models.BatchQueryIndividuationTextResponseBodyTextList()
                self.text_list.append(temp_model.from_map(k1))

        return self

class BatchQueryIndividuationTextResponseBodyTextList(DaraModel):
    def __init__(
        self,
        content: str = None,
        create_time: str = None,
        error_msg: str = None,
        item_id: str = None,
        project_id: str = None,
        status: str = None,
        task_id: str = None,
        text_id: str = None,
        update_time: str = None,
        user_id: str = None,
    ):
        self.content = content
        self.create_time = create_time
        self.error_msg = error_msg
        self.item_id = item_id
        self.project_id = project_id
        self.status = status
        self.task_id = task_id
        self.text_id = text_id
        self.update_time = update_time
        self.user_id = user_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.content is not None:
            result['content'] = self.content

        if self.create_time is not None:
            result['createTime'] = self.create_time

        if self.error_msg is not None:
            result['errorMsg'] = self.error_msg

        if self.item_id is not None:
            result['itemId'] = self.item_id

        if self.project_id is not None:
            result['projectId'] = self.project_id

        if self.status is not None:
            result['status'] = self.status

        if self.task_id is not None:
            result['taskId'] = self.task_id

        if self.text_id is not None:
            result['textId'] = self.text_id

        if self.update_time is not None:
            result['updateTime'] = self.update_time

        if self.user_id is not None:
            result['userId'] = self.user_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('content') is not None:
            self.content = m.get('content')

        if m.get('createTime') is not None:
            self.create_time = m.get('createTime')

        if m.get('errorMsg') is not None:
            self.error_msg = m.get('errorMsg')

        if m.get('itemId') is not None:
            self.item_id = m.get('itemId')

        if m.get('projectId') is not None:
            self.project_id = m.get('projectId')

        if m.get('status') is not None:
            self.status = m.get('status')

        if m.get('taskId') is not None:
            self.task_id = m.get('taskId')

        if m.get('textId') is not None:
            self.text_id = m.get('textId')

        if m.get('updateTime') is not None:
            self.update_time = m.get('updateTime')

        if m.get('userId') is not None:
            self.user_id = m.get('userId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class TextTaskCreateCmd(DaraModel):
    def __init__(
        self,
        agent_id: str = None,
        content_requirement: str = None,
        idempotent_id: str = None,
        industry: str = None,
        introduction: str = None,
        number: int = None,
        point: str = None,
        reference_tag: main_models.ReferenceTag = None,
        related_rag_ids: List[int] = None,
        stream_api: bool = None,
        style: str = None,
        target: str = None,
        text_mode_type: str = None,
        theme: str = None,
        themes: List[str] = None,
    ):
        self.agent_id = agent_id
        self.content_requirement = content_requirement
        self.idempotent_id = idempotent_id
        self.industry = industry
        self.introduction = introduction
        # This parameter is required.
        self.number = number
        self.point = point
        self.reference_tag = reference_tag
        self.related_rag_ids = related_rag_ids
        self.stream_api = stream_api
        # This parameter is required.
        self.style = style
        self.target = target
        # This parameter is required.
        self.text_mode_type = text_mode_type
        self.theme = theme
        self.themes = themes

    def validate(self):
        if self.reference_tag:
            self.reference_tag.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.agent_id is not None:
            result['agentId'] = self.agent_id

        if self.content_requirement is not None:
            result['contentRequirement'] = self.content_requirement

        if self.idempotent_id is not None:
            result['idempotentId'] = self.idempotent_id

        if self.industry is not None:
            result['industry'] = self.industry

        if self.introduction is not None:
            result['introduction'] = self.introduction

        if self.number is not None:
            result['number'] = self.number

        if self.point is not None:
            result['point'] = self.point

        if self.reference_tag is not None:
            result['referenceTag'] = self.reference_tag.to_map()

        if self.related_rag_ids is not None:
            result['relatedRagIds'] = self.related_rag_ids

        if self.stream_api is not None:
            result['streamApi'] = self.stream_api

        if self.style is not None:
            result['style'] = self.style

        if self.target is not None:
            result['target'] = self.target

        if self.text_mode_type is not None:
            result['textModeType'] = self.text_mode_type

        if self.theme is not None:
            result['theme'] = self.theme

        if self.themes is not None:
            result['themes'] = self.themes

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('agentId') is not None:
            self.agent_id = m.get('agentId')

        if m.get('contentRequirement') is not None:
            self.content_requirement = m.get('contentRequirement')

        if m.get('idempotentId') is not None:
            self.idempotent_id = m.get('idempotentId')

        if m.get('industry') is not None:
            self.industry = m.get('industry')

        if m.get('introduction') is not None:
            self.introduction = m.get('introduction')

        if m.get('number') is not None:
            self.number = m.get('number')

        if m.get('point') is not None:
            self.point = m.get('point')

        if m.get('referenceTag') is not None:
            temp_model = main_models.ReferenceTag()
            self.reference_tag = temp_model.from_map(m.get('referenceTag'))

        if m.get('relatedRagIds') is not None:
            self.related_rag_ids = m.get('relatedRagIds')

        if m.get('streamApi') is not None:
            self.stream_api = m.get('streamApi')

        if m.get('style') is not None:
            self.style = m.get('style')

        if m.get('target') is not None:
            self.target = m.get('target')

        if m.get('textModeType') is not None:
            self.text_mode_type = m.get('textModeType')

        if m.get('theme') is not None:
            self.theme = m.get('theme')

        if m.get('themes') is not None:
            self.themes = m.get('themes')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class ListAvatarProjectResponseBody(DaraModel):
    def __init__(
        self,
        query_avatar_project_result_list: List[main_models.ListAvatarProjectResponseBodyQueryAvatarProjectResultList] = None,
        request_id: str = None,
    ):
        self.query_avatar_project_result_list = query_avatar_project_result_list
        self.request_id = request_id

    def validate(self):
        if self.query_avatar_project_result_list:
            for v1 in self.query_avatar_project_result_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['queryAvatarProjectResultList'] = []
        if self.query_avatar_project_result_list is not None:
            for k1 in self.query_avatar_project_result_list:
                result['queryAvatarProjectResultList'].append(k1.to_map() if k1 else None)

        if self.request_id is not None:
            result['requestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.query_avatar_project_result_list = []
        if m.get('queryAvatarProjectResultList') is not None:
            for k1 in m.get('queryAvatarProjectResultList'):
                temp_model = main_models.ListAvatarProjectResponseBodyQueryAvatarProjectResultList()
                self.query_avatar_project_result_list.append(temp_model.from_map(k1))

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        return self

class ListAvatarProjectResponseBodyQueryAvatarProjectResultList(DaraModel):
    def __init__(
        self,
        agent_id: str = None,
        error_msg: str = None,
        project_id: str = None,
        project_name: str = None,
        status: str = None,
    ):
        self.agent_id = agent_id
        self.error_msg = error_msg
        self.project_id = project_id
        self.project_name = project_name
        self.status = status

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.agent_id is not None:
            result['agentId'] = self.agent_id

        if self.error_msg is not None:
            result['errorMsg'] = self.error_msg

        if self.project_id is not None:
            result['projectId'] = self.project_id

        if self.project_name is not None:
            result['projectName'] = self.project_name

        if self.status is not None:
            result['status'] = self.status

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('agentId') is not None:
            self.agent_id = m.get('agentId')

        if m.get('errorMsg') is not None:
            self.error_msg = m.get('errorMsg')

        if m.get('projectId') is not None:
            self.project_id = m.get('projectId')

        if m.get('projectName') is not None:
            self.project_name = m.get('projectName')

        if m.get('status') is not None:
            self.status = m.get('status')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class QuerySessionInfoShrinkRequest(DaraModel):
    def __init__(
        self,
        page_no: int = None,
        page_size: int = None,
        project_id: str = None,
        status_list_shrink: str = None,
    ):
        self.page_no = page_no
        self.page_size = page_size
        self.project_id = project_id
        self.status_list_shrink = status_list_shrink

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.page_no is not None:
            result['pageNo'] = self.page_no

        if self.page_size is not None:
            result['pageSize'] = self.page_size

        if self.project_id is not None:
            result['projectId'] = self.project_id

        if self.status_list_shrink is not None:
            result['statusList'] = self.status_list_shrink

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('pageNo') is not None:
            self.page_no = m.get('pageNo')

        if m.get('pageSize') is not None:
            self.page_size = m.get('pageSize')

        if m.get('projectId') is not None:
            self.project_id = m.get('projectId')

        if m.get('statusList') is not None:
            self.status_list_shrink = m.get('statusList')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ListAnchorRequest(DaraModel):
    def __init__(
        self,
        anchor_category: str = None,
        anchor_id: str = None,
        anchor_type: str = None,
        cover_rate: str = None,
        digital_human_type: str = None,
        page_number: int = None,
        page_size: int = None,
        res_spec_type: str = None,
        use_scene: str = None,
    ):
        self.anchor_category = anchor_category
        self.anchor_id = anchor_id
        self.anchor_type = anchor_type
        self.cover_rate = cover_rate
        self.digital_human_type = digital_human_type
        self.page_number = page_number
        self.page_size = page_size
        self.res_spec_type = res_spec_type
        self.use_scene = use_scene

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.anchor_category is not None:
            result['anchorCategory'] = self.anchor_category

        if self.anchor_id is not None:
            result['anchorId'] = self.anchor_id

        if self.anchor_type is not None:
            result['anchorType'] = self.anchor_type

        if self.cover_rate is not None:
            result['coverRate'] = self.cover_rate

        if self.digital_human_type is not None:
            result['digitalHumanType'] = self.digital_human_type

        if self.page_number is not None:
            result['pageNumber'] = self.page_number

        if self.page_size is not None:
            result['pageSize'] = self.page_size

        if self.res_spec_type is not None:
            result['resSpecType'] = self.res_spec_type

        if self.use_scene is not None:
            result['useScene'] = self.use_scene

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('anchorCategory') is not None:
            self.anchor_category = m.get('anchorCategory')

        if m.get('anchorId') is not None:
            self.anchor_id = m.get('anchorId')

        if m.get('anchorType') is not None:
            self.anchor_type = m.get('anchorType')

        if m.get('coverRate') is not None:
            self.cover_rate = m.get('coverRate')

        if m.get('digitalHumanType') is not None:
            self.digital_human_type = m.get('digitalHumanType')

        if m.get('pageNumber') is not None:
            self.page_number = m.get('pageNumber')

        if m.get('pageSize') is not None:
            self.page_size = m.get('pageSize')

        if m.get('resSpecType') is not None:
            self.res_spec_type = m.get('resSpecType')

        if m.get('useScene') is not None:
            self.use_scene = m.get('useScene')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class InteractTextRequest(DaraModel):
    def __init__(
        self,
        agent_id: str = None,
        content: str = None,
        session_id: str = None,
    ):
        self.agent_id = agent_id
        self.content = content
        self.session_id = session_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.agent_id is not None:
            result['agentId'] = self.agent_id

        if self.content is not None:
            result['content'] = self.content

        if self.session_id is not None:
            result['sessionId'] = self.session_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('agentId') is not None:
            self.agent_id = m.get('agentId')

        if m.get('content') is not None:
            self.content = m.get('content')

        if m.get('sessionId') is not None:
            self.session_id = m.get('sessionId')

        return self

